@@ -49,6 +49,7 @@ static state curstate;
 static GtkWidget *applet;
 static GtkWidget *pixmap; 
 static GtkWidget *dialogWindow; 
+static GtkWidget *operationDialogWindow;
 static GtkWidget *pb;
 /* static GtkWidget *dialog; */
 guint timeout_handler_id;
@@ -83,6 +84,7 @@ void gpilotd_request_completed(const gchar *id,unsigned long handle) {
 	show_message_dialog("Pilot %s has completed request %d",
 			    strlen(id)==0?"(noname)":id,
 			    handle);
+	gnome_dialog_close(GNOME_DIALOG(operationDialogWindow));
 }
 
 void gpilotd_userinfo_requested(const gchar *device,const GNOME_Pilot_PilotUser *user) {
@@ -92,14 +94,43 @@ void gpilotd_sysinfo_requested(const gchar *id,const GNOME_Pilot_SysInfo *info)
   g_message("pilot %s",id);
 }
 
-void gpilotd_conduit_start(const gchar *id, 
-			   const gchar *conduit_name, 
-			   const gchar *db_name) { 
-	g_message("conduit_start(%s,%s,%s)",id,conduit_name,db_name);
+void 
+gpilotd_conduit_start(const gchar *id, 
+		      const gchar *conduit, 
+		      const gchar *db_name) { 
+	g_message("conduit_start(%s,%s,%s)",id,conduit,db_name);
 }
 
-void gpilotd_conduit_end(const gchar *id) { 
-	g_message("conduit_end(%s)",id);
+void 
+gpilotd_conduit_end(const gchar *id,
+		    const gchar *conduit) { 
+	g_message("conduit_end(%s,%s)",id,conduit);
+}
+
+void 
+gpilotd_conduit_progress(const gchar *id, 
+			 const gchar *conduit, 
+			 long current, 
+			 long total) {
+	gfloat tot_f,cur_f;
+	tot_f = total;
+	cur_f = current;
+	g_message("%s : %s : %d/%d = %d%%",id, conduit, current, 
+		  total,abs(cur_f/(tot_f/100)));
+}
+
+void 
+gpilotd_conduit_message(const gchar *id, 
+			const gchar *conduit, 
+			const gchar *message) {
+	g_message("conduit_message(%s,%s,%s)",id,conduit,message);
+}
+
+void 
+gpilotd_conduit_error(const gchar *id, 
+		      const gchar *conduit, 
+		      const gchar *message) {
+	g_warning("conduit_error(%s,%s,%s)",id,conduit,message);
 }
 
 /******************************************************************/
@@ -187,7 +218,7 @@ timeout(gpointer data)
 			curstate = waiting;
 			pilot_draw(GTK_WIDGET(data));
 		} else {
-			//timeout_handler_id = gtk_timeout_add(3000,timeout,data);
+			/* timeout_handler_id = gtk_timeout_add(3000,timeout,data); */
 		}
 		return TRUE;
 	} break;
@@ -279,7 +310,11 @@ load_properties(char *cfgpath)
   
   gnome_config_push_prefix(cfgpath);
   properties.exec_when_clicked = gnome_config_get_string("exec_when_clicked=gpilotd-control-applet");
-  properties.backupdir = gnome_config_get_string("backupdir=");
+  properties.backupdir = gnome_config_get_string("backupdir");
+  /* FIXME: read from backup conduit settings instead */
+  if ( properties.backupdir == NULL) {
+	  properties.backupdir = g_strdup_printf("%s/pilot",g_get_home_dir());
+  }
   properties.text_limit = gnome_config_get_int("text_limit=10240");
   properties.popups = gnome_config_get_bool("pop-ups=true");
 
@@ -313,6 +348,7 @@ apply_restore_directory_cb(GnomePropertyBox * pb, gint page, gpointer data)
 	if (new_list) {
 		g_free(properties.backupdir);
 		properties.backupdir = g_strdup(new_list);
+		g_message("backupdir = %s",properties.backupdir);
 	}
 }
 
@@ -364,7 +400,6 @@ static void cancel_restore(GnomeDialog *w,gpointer data) {
 static void
 restore_dialog(AppletWidget * w, gpointer data)
 {
-	GtkWidget *dialogWindow;
 	int handle;
 	gchar *backupdir;
 	gchar *backupdir_key;
@@ -374,17 +409,17 @@ restore_dialog(AppletWidget * w, gpointer data)
 		return;
 	}
 		
-	handle = gpilotd_restore(properties.pilot_id,backupdir,GNOME_Pilot_PERSISTENT,0);
+	handle = gpilotd_restore(properties.pilot_id,properties.backupdir,GNOME_Pilot_PERSISTENT,0);
 
 	if (handle>0) {
-		dialogWindow = gnome_message_box_new(_("Press synchronize on the cradle to restore\n" 
-						       " or cancel the operation."),
-						     GNOME_MESSAGE_BOX_GENERIC,
-						     GNOME_STOCK_BUTTON_CANCEL,
-						     NULL);
-		gnome_dialog_button_connect(GNOME_DIALOG(dialogWindow),0,
+		operationDialogWindow = gnome_message_box_new(_("Press synchronize on the cradle to restore\n" 
+								" or cancel the operation."),
+							      GNOME_MESSAGE_BOX_GENERIC,
+							      GNOME_STOCK_BUTTON_CANCEL,
+							      NULL);
+		gnome_dialog_button_connect(GNOME_DIALOG(operationDialogWindow),0,
 					    cancel_restore,GINT_TO_POINTER(handle));
-		gnome_dialog_run_and_close(GNOME_DIALOG(dialogWindow));
+		gnome_dialog_run_and_close(GNOME_DIALOG(operationDialogWindow));
 	} else {
 		show_warning_dialog(_("Restore request failed"));
 	}
@@ -625,7 +660,7 @@ create_pilot_widget(GtkWidget *window)
 
   timeout_handler_id = gtk_timeout_add(1000,timeout,pixmap);
   
-  gtk_signal_connect(GTK_OBJECT(applet),"session-save",
+  gtk_signal_connect(GTK_OBJECT(applet),"save_session",
 		     GTK_SIGNAL_FUNC(applet_save_session),
 		     NULL);
   gtk_signal_connect(GTK_OBJECT(applet),"destroy",
