@@ -2,7 +2,7 @@
 /*                                                                          */
 /* Copyright 1998 Red Hat Software                                          */
 /* Author: Michael Fulbright <msf@redhat.com>                               */
-
+#include <config.h>
 #include <pwd.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -61,17 +61,41 @@ void gpilotd_request_completed(const gchar *id,unsigned long handle) {
   gnome_dialog_close(GNOME_DIALOG(dialogWindow));
 }
 
-
-void gpilotd_conduit_start(const gchar *id, 
-			   const gchar *conduit_name, 
-			   const gchar *db_name) { 
-	g_message("conduit_start(%s,%s,%s)",id,conduit_name,db_name);
+void 
+gpilotd_conduit_start(const gchar *id, 
+		      const gchar *conduit, 
+		      const gchar *db_name) { 
+	g_message("conduit_start(%s,%s,%s)",id,conduit,db_name);
 }
 
-void gpilotd_conduit_end(const gchar *id) { 
+void 
+gpilotd_conduit_end(const gchar *id,
+		    const gchar *conduit) { 
 	g_message("conduit_end(%s)",id);
 }
 
+void 
+gpilotd_conduit_progress(const gchar *id, 
+			 const gchar *conduit, 
+			 long total, 
+			 long current) {
+	g_message("conduit_progress(%s,%s,%d/%d)",id, conduit, current, total);
+}
+
+void 
+gpilotd_conduit_message(const gchar *id, 
+			const gchar *conduit, 
+			const gchar *message) {
+	g_message("conduit_message(%s,%s,%s)",id,conduit,message);
+}
+
+void 
+gpilotd_conduit_error(const gchar *id, 
+		      const gchar *conduit, 
+		      const gchar *message) {
+	g_warning("conduit_error(%s,%s,%s)",id,conduit,message);
+}
+
 void gpilotd_userinfo_requested(const gchar *device,const GNOME_Pilot_PilotUser *user) {
   g_message("device %s sent userinfo",device);
   g_message("user->userID   = %d",user->userID);
@@ -152,15 +176,21 @@ doTrySettings(GtkWidget *widget, PilotState *pilotState)
     readPilotCfg(pilotCfgWindow, &pilotState);
     readSyncCfg(pilotCfgWindow, &pilotState);
 
-    if(pilotState->device->device_name==NULL) {
+    if(pilotState->device->port==NULL) {
       run_error_dialog(_("Please specify a cradle port"));
       return;
     }
 
-    g_message("checking rw on %s",pilotState->device->device_name);
-    if(access(pilotState->device->device_name,R_OK|W_OK)) {
-      run_error_dialog(_("Read/Write permissions on %s failed"),pilotState->device->device_name);
-      return;
+    g_message("checking rw on %s",pilotState->device->port);
+    if(access(pilotState->device->port,R_OK|W_OK)) {
+	    char *tmp;
+	    tmp = g_strdup_printf("%s\n%s\n%s",
+				  _("Read/Write permissions failed on"),
+				  pilotState->device->port,
+				  _("Check the permissions on the device and retry"));	  
+	    run_error_dialog(tmp);
+	    g_free(tmp);
+	    return;
     }
 
 /* revert only back to original state, so no need to save current */
@@ -321,7 +351,7 @@ static void
 get_from_pilot_cb() 
 {
 	int handle;
-	handle = gpilotd_get_user_info(curState->device->device_name,GNOME_Pilot_PERSISTENT,0);
+	handle = gpilotd_get_user_info(curState->device->name,GNOME_Pilot_PERSISTENT,0);
 	/* FIXME: check handle>0 here */
 	run_sync_dialog(handle);
 
@@ -337,7 +367,7 @@ send_to_pilot_cb()
 	
 	user.userID = curState->pilot->pilot_id;
 	user.username = curState->pilot->pilot_username;
-	handle = gpilotd_set_user_info(curState->device->device_name,user,GNOME_Pilot_PERSISTENT,0);
+	handle = gpilotd_set_user_info(curState->device->name,user,GNOME_Pilot_PERSISTENT,0);
 	/* FIXME: check handle>0 here */
 	run_sync_dialog(handle);
 }
@@ -521,18 +551,18 @@ setDeviceCfg(GtkWidget *devcfg, PilotState *state)
 	   eg. containing COM1, COM2 ... */
 	/* initialize the device setting */
 	for (i=0, sel=-1; deviceList[i]; i++) {
-	    if (!strncmp(deviceList[i], state->device->device_name,
+	    if (!strncmp(deviceList[i], state->device->port,
 			 strlen(deviceList[i])))
 		sel = i;
 	}
 	if (sel < 0) {
 	    g_message(_("Warning - unrecognized device %s, "
-		        "changing to /dev/pilot"), state->device->device_name);
+		        "changing to /dev/pilot"), state->device->port);
 	    sel = 0;
 	}
 #endif
 	ignore_changes = TRUE;
-	gtk_entry_set_text(GTK_ENTRY(port_entry), state->device->device_name);
+	gtk_entry_set_text(GTK_ENTRY(port_entry), state->device->port);
 	ignore_changes = FALSE;
 
 	/* now do the speed selection */
@@ -577,16 +607,16 @@ readDeviceCfg(GtkWidget *devcfg, PilotState **state)
 	p->device = g_new0(GPilotDevice, 1);
     }
 
-    if (p->device->device_name)
-	g_free(p->device->device_name);
-    p->device->device_name = g_strdup(gtk_entry_get_text(GTK_ENTRY(port_entry)));
+    if (p->device->port)
+	g_free(p->device->port);
+    p->device->port = g_strdup(gtk_entry_get_text(GTK_ENTRY(port_entry)));
 
 #if 0
     dlist = GTK_CLIST(port_clist)->selection;
     sel = GPOINTER_TO_INT(dlist->data);
-    if (p->device->device_name)
-	g_free(p->device->device_name);
-    p->device->device_name = g_strdup(deviceList[sel]);
+    if (p->device->port)
+	g_free(p->device->port);
+    p->device->port = g_strdup(deviceList[sel]);
 #endif
 
     dlist = GTK_CLIST(speed_clist)->selection;
@@ -687,7 +717,7 @@ setPilotCfg(GtkWidget *pilotcfg, PilotState *state)
 	    g_snprintf(num,sizeof(num),"%d",getuid());
 	    gtk_entry_set_text(GTK_ENTRY(id), num);
 	    gtk_entry_set_text(GTK_ENTRY(name), g_get_real_name());
-	    gtk_entry_set_text(GTK_ENTRY(pname), "My Pilot");
+	    gtk_entry_set_text(GTK_ENTRY(pname), "MyPilot");
     }
     ignore_changes = FALSE;
 }
@@ -884,6 +914,10 @@ pilot_capplet_setup(void)
 int
 main( int argc, char *argv[] )
 {
+
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
 	/* we're a capplet */
 	switch(gnome_capplet_init ("gpilot control applet", VERSION, argc, argv, 
 				   NULL,
