@@ -538,7 +538,7 @@ main( int argc, char *argv[] )
 
         load_configuration(&origState,pilotId);
         curState = dupe_configuration(origState);
-        conduit = gpilotd_conduit_mgmt_new("expense_conduit");
+        conduit = gpilotd_conduit_mgmt_new("expense_conduit",pilotId);
 
         org_activation_state = activated = gpilotd_conduit_mgmt_is_enabled(conduit,pilotId);
     
