@@ -19,7 +19,7 @@
 
 #include "memo_file_conduit.h"
 
-#define CONDUIT_VERSION "0.5"
+#define CONDUIT_VERSION "0.6"
 
 static IterateData *
 new_iterate_data(int _flag,int _archived) 
@@ -367,7 +367,7 @@ iterate_foreach(MemoLocalRecord *local,IterateData *d)
 		else
 			d->first = local;
 		d->prev = local;
-  }
+	}
 }
 
 static void 
@@ -566,11 +566,11 @@ load_records(GnomePilotConduitStandardAbs *abs)
 					local->filename = (gchar*)g_malloc(FILENAME_MAX);
 					g_snprintf(local->filename,FILENAME_MAX,"%s/%s",filename,l_de->d_name);
 					if((info=g_hash_table_lookup(loadinfo,local->filename))!=NULL) {
-						g_hash_table_remove(loadinfo,local->filename);
-						g_free(info);
 						local->local.ID = info->id;
 						local->local.secret = info->secret;
 						local->mtime=info->mtime;
+						g_hash_table_remove(loadinfo,local->filename);
+						g_free(info);
 					} else {
 						local->local.ID = 0;
 						local->local.secret = 0;
@@ -610,7 +610,6 @@ pre_sync(GnomePilotConduit *c, GnomePilotDBInfo *dbi)
 
 	LOG("PreSync",1);
 
-
 	GET_CONDUIT_DATA(c)->dbi=dbi;
   
 	load_records((GnomePilotConduitStandardAbs*)c); 
@@ -622,7 +621,11 @@ pre_sync(GnomePilotConduit *c, GnomePilotDBInfo *dbi)
 	}
 	unpack_MemoAppInfo(&(GET_CONDUIT_DATA(c)->ai),buf,l);
 	g_free(buf);
-	
+
+	/* If local store is empty force the slow sync. */
+	if(g_list_length(GET_CONDUIT_DATA(c)->records)==0){
+		gnome_pilot_conduit_standard_set_slow((GnomePilotConduitStandard*)c);
+	}
 	return 0;
 }
 
@@ -634,6 +637,7 @@ match_record	(GnomePilotConduitStandardAbs *abs,
 {
 	GList *tmp;
 	LOG("MatchRecord",1);
+
 	g_return_val_if_fail(local!=NULL,-1);
 	g_return_val_if_fail(remote!=NULL,-1);
 
@@ -715,7 +719,10 @@ store_remote (GnomePilotConduitStandardAbs *abs,
 		
 	} else {
 		local = tmp->data;
-		if(local->record) g_free(local->record);
+		if(local->record) {
+			g_free(local->record);
+			local->record=NULL;
+		}
 	}
 
 	local->local.ID = remote->ID; 
@@ -970,8 +977,8 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONFIG,cc);
 	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONDUIT,cd);
 	
-	if(cc->open_secret) gtk_object_set_data(GTK_OBJECT(retval),"db_open_mode",
-						GINT_TO_POINTER(dlpOpenReadWrite|dlpOpenSecret));
+	if(cc->open_secret) gnome_pilot_conduit_standard_abs_set_db_open_mode(GNOME_PILOT_CONDUIT(retval),
+									      dlpOpenReadWrite|dlpOpenSecret);
 	return GNOME_PILOT_CONDUIT (retval);
 }
 
