@@ -387,10 +387,18 @@ standard_abs_compute_attr_field(PilotRecord *remote)
 }
 
 static void
-gnome_pilot_conduit_standard_abs_init (GnomePilotConduitStandardAbs *pilot_conduit_standard_abs)
+gnome_pilot_conduit_standard_abs_init (GnomePilotConduitStandardAbs *conduit)
 {
-	pilot_conduit_standard_abs->recordIdsToIgnore = NULL;
-	pilot_conduit_standard_abs->totalRecords = 0;
+	conduit->record_ids_to_ignore = NULL;
+	conduit->total_records = 0;
+	conduit->num_local_records = -1;
+	conduit->num_updated_local_records = -1;
+	conduit->num_new_local_records = -1;
+	conduit->num_deleted_local_records = -1;
+	conduit->db_open_mode = 0;
+	conduit->progress = 0; /* as usual... */
+	conduit->total_progress = 0; /* oh no!... */
+
 }
 
 static gint
@@ -407,16 +415,19 @@ gnome_pilot_conduit_standard_real_copy_to_pilot     (GnomePilotConduitStandard *
 
 	conduit = GNOME_PILOT_CONDUIT_STANDARD_ABS (conduit_standard);
 
+	/* Open db and prepare conduit */
 	standard_abs_open_db(conduit, dbinfo);
-
-	if( gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo) != 0) {
+	if (gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo) != 0) {
 		g_warning(_("Conduits initialization failed, aborting operation"));
 		return -1;
 	}
+	
+	/* nuke all records */
 	if (dlp_DeleteRecord (dbinfo->pilot_socket, dbinfo->db_handle, 1, 0) < 0) {
 		g_warning(_("Unable to delete all records in pilot database, aborting operation."));
 		return -1;
 	}
+
 	while (gnome_pilot_conduit_standard_abs_iterate (conduit, &local) && local) {
 		if (local->archived) {
 			retval = gnome_pilot_conduit_standard_abs_clear_status_archive_local (conduit, local);
@@ -424,7 +435,7 @@ gnome_pilot_conduit_standard_real_copy_to_pilot     (GnomePilotConduitStandard *
 		} else if (local->attr != GnomePilotRecordDeleted) {
 			PilotRecord *remote;
 			gnome_pilot_conduit_standard_abs_transmit (conduit, local, &remote);
-			if(remote==NULL) {
+			if (remote==NULL) {
 			  g_warning(_("Conduit did not return a record"));
 			  break;
 			}
@@ -437,8 +448,10 @@ gnome_pilot_conduit_standard_real_copy_to_pilot     (GnomePilotConduitStandard *
 						 remote->record,
 						 remote->length,
 						 &assigned_id);
-			if(retval>0) gnome_pilot_conduit_standard_abs_set_pilot_id(conduit,local,assigned_id);
+			if (retval>0) gnome_pilot_conduit_standard_abs_set_pilot_id(conduit,local,assigned_id);
 		        gnome_pilot_conduit_standard_abs_free_transmit (conduit, local, &remote);
+			/* HEST */
+			/* gnome_pilot_conduit_progress(conduit,?,?); */
 		}
 	}
 
@@ -462,17 +475,21 @@ gnome_pilot_conduit_standard_real_copy_from_pilot   (GnomePilotConduitStandard *
 	conduit = GNOME_PILOT_CONDUIT_STANDARD_ABS (conduit_standard);
 
 	remote.record = buffer;
-	standard_abs_open_db(conduit,dbinfo);
 
-	if(gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
+	/* Open db and prepare conduit */
+	standard_abs_open_db(conduit,dbinfo);
+	if (gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
 		g_warning(_("Conduits initialization failed, aborting operation"));
 		return -1;
 	}
+
+	/* nuke all records */
 	if (gnome_pilot_conduit_standard_abs_delete_all (conduit) < 0) {
 		g_warning(_("Unable to delete all records in local database, aborting operation."));
 		return -1;
 	}
 
+	/* copy all records */
 	while (dlp_ReadRecordByIndex (dbinfo->pilot_socket,
 				      dbinfo->db_handle,
 				      index,
@@ -494,6 +511,8 @@ gnome_pilot_conduit_standard_real_copy_from_pilot   (GnomePilotConduitStandard *
 			gnome_pilot_conduit_standard_abs_store_remote (conduit, &remote);
 		}
 		index++;
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_records,index);
 	}
 
 	standard_abs_close_db_and_purge_local(conduit,dbinfo);
@@ -512,8 +531,9 @@ gnome_pilot_conduit_standard_real_merge_to_pilot    (GnomePilotConduitStandard *
 
 	conduit = GNOME_PILOT_CONDUIT_STANDARD_ABS (conduit_standard);
 
+	/* Open db and prepare conduit */
 	standard_abs_open_db(conduit, dbinfo);
-	if(gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
+	if (gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
 		g_warning(_("Conduits initialization failed, aborting operation"));
 		return -1;
 	}
@@ -535,8 +555,9 @@ gnome_pilot_conduit_standard_real_merge_from_pilot  (GnomePilotConduitStandard *
 
 	conduit = GNOME_PILOT_CONDUIT_STANDARD_ABS (conduit_standard);
 
+	/* Open db and prepare conduit */
 	standard_abs_open_db(conduit, dbinfo);
-	if(gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
+	if (gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
 		g_warning(_("Conduits initialization failed, aborting operation"));
 		return -1;
 	}
@@ -559,19 +580,41 @@ gnome_pilot_conduit_standard_real_synchronize       (GnomePilotConduitStandard *
 
 	conduit = GNOME_PILOT_CONDUIT_STANDARD_ABS(conduit_standard);
 
+	/* Open db and prepare conduit */
 	standard_abs_open_db(conduit, dbinfo);
-	if(gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
+	if (gnome_pilot_conduit_standard_abs_pre_sync(conduit, dbinfo)!=0) {
 		g_warning(_("Conduits initialization failed, aborting operation"));
 		return -1;
 	}
 
+	/* Set the counters for the progress bar, note, total_records is set
+	   in standard_abs_open_db */
+	conduit->total_progress = 0;
+	if (conduit->num_local_records == -1) {
+		conduit->num_local_records = conduit->total_records;
+	}
+	if (conduit->num_updated_local_records == -1) {
+		conduit->num_updated_local_records = conduit->total_records;
+	}
+	conduit->total_progress += conduit->num_updated_local_records;
+	if (conduit->num_new_local_records == -1) {
+		conduit->num_new_local_records = conduit->total_records;
+	}
+	conduit->total_progress += conduit->num_deleted_local_records;
+	if (conduit->num_deleted_local_records == -1) {
+		conduit->num_deleted_local_records = conduit->total_records;
+	}
+	conduit->total_progress += conduit->num_deleted_local_records;
+
+	/* Decide on fast sync or slow sync */
       	if (conduit_standard->slow==FALSE && gpilot_sync_pc_match (dbinfo)==TRUE) {
 		retval = FastSync(dbinfo->pilot_socket, dbinfo->db_handle, conduit);
 	} else {
+		conduit->total_progress += conduit->total_records;
 		retval = SlowSync(dbinfo->pilot_socket, dbinfo->db_handle, conduit);
 	}
 	/* now disable the slow=true setting, so it doens't pass on to next time */
-	if(conduit_standard->slow==TRUE)
+	if (conduit_standard->slow==TRUE)
 		conduit_standard->slow = FALSE;
 
 	standard_abs_merge_to_remote(conduit, dbinfo->pilot_socket, dbinfo->db_handle, SyncBothWays );
@@ -892,6 +935,47 @@ gnome_pilot_conduit_standard_abs_pre_sync (GnomePilotConduitStandardAbs *conduit
 	return retval;
 }
 
+void
+gnome_pilot_conduit_standard_abs_set_num_local_records (GnomePilotConduitStandardAbs *conduit,
+							gint num) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit));
+	conduit->num_local_records = num;
+}
+
+void
+gnome_pilot_conduit_standard_abs_set_num_updated_local_records (GnomePilotConduitStandardAbs *conduit,
+								gint num) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit));
+       	conduit->num_updated_local_records = num;
+}
+
+void
+gnome_pilot_conduit_standard_abs_set_num_new_local_records (GnomePilotConduitStandardAbs *conduit,
+								gint num) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit));
+	conduit->num_new_local_records = num;
+}
+
+void
+gnome_pilot_conduit_standard_abs_set_num_deleted_local_records (GnomePilotConduitStandardAbs *conduit,
+								gint num) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit));
+	conduit->num_deleted_local_records = num;
+}
+
+void 
+gnome_pilot_conduit_standard_abs_set_db_open_mode (GnomePilotConduitStandardAbs *conduit,
+						   gint mode) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit));
+	
+	conduit->db_open_mode = mode;
+}
+
 /* Deletes a remote record from the pilot */
 static void
 standard_abs_delete_from_pilot(GnomePilotConduitStandardAbs *conduit,
@@ -904,7 +988,7 @@ standard_abs_delete_from_pilot(GnomePilotConduitStandardAbs *conduit,
 	g_message("gpilotd: deleting record %ld from pilot",remote->ID);
 
 	err = dlp_DeleteRecord(handle,db,0,remote->ID);
-	if(err<=0) {
+	if (err<=0) {
 		g_warning("dlp_DeleteRecord returned %d",err);
 	}
 }
@@ -912,7 +996,7 @@ standard_abs_delete_from_pilot(GnomePilotConduitStandardAbs *conduit,
 /* updates or adds a local record to the pilot. Note, that after calling this,
    the record has the dirty bit set.
    FIXME: Remember these id's and ignore during SyncRecord
-   Use recordIdsToIgnore, add the recordId to this list, then let sync_record
+   Use record_ids_to_ignore, add the recordId to this list, then let sync_record
    check the id of the record to sync as early as possible, and abort if match 
 */
 static recordid_t
@@ -928,7 +1012,7 @@ standard_abs_add_to_pilot (GnomePilotConduitStandardAbs *conduit,
 	g_message("gpilotd: adding record to pilot");
 
 	err = gnome_pilot_conduit_standard_abs_transmit (conduit, local, &remote);
-	if(err < 0 || remote==NULL) {
+	if (err < 0 || remote==NULL) {
 	  g_warning(_("Conduit did not return a record"));
 	}
 	gnome_pilot_conduit_standard_abs_set_status (conduit, local, GnomePilotRecordNothing);
@@ -940,12 +1024,12 @@ standard_abs_add_to_pilot (GnomePilotConduitStandardAbs *conduit,
 			       remote->record,
 			       remote->length,
 			       &assigned_id);
-	if(err<=0) {
+	if (err<=0) {
 		g_warning("dlp_WriteRecord returned %d",err);
 		return 0;
 	}
 
-	conduit->recordIdsToIgnore = g_slist_prepend(conduit->recordIdsToIgnore,
+	conduit->record_ids_to_ignore = g_slist_prepend(conduit->record_ids_to_ignore,
 						     GINT_TO_POINTER(assigned_id));
 	gnome_pilot_conduit_standard_abs_free_transmit (conduit, local, &remote);
 	
@@ -993,7 +1077,7 @@ standard_abs_sync_record (GnomePilotConduitStandardAbs *conduit,
 	free_match = FALSE;
 
 	if (local==NULL && remote!=NULL) {
-		if(g_slist_find(conduit->recordIdsToIgnore,GINT_TO_POINTER(remote->ID))!=NULL) {
+		if (g_slist_find(conduit->record_ids_to_ignore,GINT_TO_POINTER(remote->ID))!=NULL) {
 			g_message("gpilotd: this record has already been processed");
 			return 0;
 		}
@@ -1001,7 +1085,7 @@ standard_abs_sync_record (GnomePilotConduitStandardAbs *conduit,
 		free_match = TRUE;
 	} else if (remote==NULL && local!=NULL) {
 		int index;
-		if(g_slist_find(conduit->recordIdsToIgnore,GINT_TO_POINTER(local->ID))!=NULL) {
+		if (g_slist_find(conduit->record_ids_to_ignore,GINT_TO_POINTER(local->ID))!=NULL) {
 			g_message("gpilotd: this record has already been processed");
 			return 0;
 		}
@@ -1027,11 +1111,11 @@ standard_abs_sync_record (GnomePilotConduitStandardAbs *conduit,
 
 	if (local) {
 		/* local record exists */
-		if(remote->archived) {
+		if (remote->archived) {
 #if 0	
 			switch(local->attr) {
 			case GnomePilotRecordModified:
-				if(remove->attr == GnomePilotRecordModified) {
+				if (remove->attr == GnomePilotRecordModified) {
 					if (gnome_pilot_conduit_standard_abs_compare(conduit,local,remote) != 0) {
 					 	/* CASE 14 */
 					} else {
@@ -1239,6 +1323,8 @@ standard_abs_check_locally_deleted_records(GnomePilotConduitStandardAbs *conduit
 	while(gnome_pilot_conduit_standard_abs_iterate_specific (conduit, &local, GnomePilotRecordDeleted, 0)) {
 		g_message("gpilotd: locally deleted record...");
 		standard_abs_sync_record(conduit, handle, db, local, NULL, direction);
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_progress, ++conduit->progress);
 	}
 	return 0;
 }
@@ -1251,6 +1337,7 @@ standard_abs_merge_to_remote (GnomePilotConduitStandardAbs *conduit,
 			      StandardAbsSyncDirection direction) 
 {
 	LocalRecord *local;
+
 	local = NULL;
 
 	g_assert(conduit!=NULL);
@@ -1265,6 +1352,8 @@ standard_abs_merge_to_remote (GnomePilotConduitStandardAbs *conduit,
 			gnome_pilot_conduit_standard_abs_set_pilot_id (conduit, 
 								       local, 
 								       assigned_id);
+			gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+						     conduit->total_progress, ++conduit->progress);
 		}
 
 	/* 
@@ -1274,6 +1363,8 @@ standard_abs_merge_to_remote (GnomePilotConduitStandardAbs *conduit,
 	*/
 	while(gnome_pilot_conduit_standard_abs_iterate_specific (conduit, &local, GnomePilotRecordModified, 0)) {
 		standard_abs_sync_record(conduit, handle, db, local, NULL, direction);
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_progress,++conduit->progress);
 	}
 
 	return 0;
@@ -1305,8 +1396,10 @@ standard_abs_merge_to_local (GnomePilotConduitStandardAbs *conduit,
 		     remote.attr == GnomePilotRecordModified)
 			standard_abs_sync_record (conduit, handle, db, NULL, &remote, direction);
 		index++;
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_progress,index);
 	}
-
+	conduit->progress = index;
 
 	return 0;
 }
@@ -1339,7 +1432,10 @@ SlowSync (int handle,
 		standard_abs_compute_attr_field(&remote);
 		standard_abs_sync_record (conduit, handle, db, NULL, &remote, SyncBothWays);
 		index++;
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_progress,index);
 	}
+	conduit->progress = index;
 
 	return retval;
 }
@@ -1374,7 +1470,10 @@ FastSync (int handle,
 					&remote.category) >= 0) {
 		standard_abs_compute_attr_field(&remote);
 		standard_abs_sync_record (conduit, handle, db, NULL, &remote, SyncBothWays);
+		gnome_pilot_conduit_progress(GNOME_PILOT_CONDUIT(conduit),
+					     conduit->total_progress,index);
 	}
+	conduit->progress = index;
 
 	return retval;
 }
@@ -1388,14 +1487,14 @@ gpilot_sync_pc_match(GnomePilotDBInfo *dbinfo)
 
 #if 0
 	/* FIXME: these are for debug purposes */
-	if(stamp->sync_PC_Id != dbinfo->pu->lastSyncPC) g_message("Cannot Fast Synchronize, SyncPC id failed");
-	if(stamp->last_sync_date != dbinfo->pu->successfulSyncDate) g_message("Cannot Fast Synchronize, SyncDate failed");
+	if (stamp->sync_PC_Id != dbinfo->pu->lastSyncPC) g_message("Cannot Fast Synchronize, SyncPC id failed");
+	if (stamp->last_sync_date != dbinfo->pu->successfulSyncDate) g_message("Cannot Fast Synchronize, SyncDate failed");
 #endif
 /*
-	if(stamp->sync_PC_Id == dbinfo->pu->lastSyncPC &&
+	if (stamp->sync_PC_Id == dbinfo->pu->lastSyncPC &&
 	   stamp->last_sync_date==dbinfo->pu->successfulSyncDate) {
 */
-	if(stamp->sync_PC_Id == dbinfo->pu->lastSyncPC) {
+	if (stamp->sync_PC_Id == dbinfo->pu->lastSyncPC) {
 		return TRUE;
 	}
 	return FALSE;
@@ -1405,18 +1504,15 @@ void
 standard_abs_open_db(GnomePilotConduitStandardAbs *conduit,
 		     GnomePilotDBInfo *dbinfo)
 {
-	gint cd;
 	gchar *name;
   
 	g_assert(conduit!=NULL);
 	g_assert(dbinfo!=NULL);
 
 	name = g_strdup(gnome_pilot_conduit_standard_get_db_name (GNOME_PILOT_CONDUIT_STANDARD(conduit)));
-	cd = 0;
-	cd = (int)gtk_object_get_data(GTK_OBJECT(conduit),"db_open_mode");
-	if(cd!=0) {
-		g_message("gpilotd: open_db: opening with %d\n",cd);
-		dlp_OpenDB (dbinfo->pilot_socket, 0, cd, 
+	if (conduit->db_open_mode!=0) {
+		g_message("gpilotd: open_db: opening with %d\n",conduit->db_open_mode);
+		dlp_OpenDB (dbinfo->pilot_socket, 0, conduit->db_open_mode, 
 			    name, 
 			    &(dbinfo->db_handle));
 	} else {
@@ -1425,6 +1521,7 @@ standard_abs_open_db(GnomePilotConduitStandardAbs *conduit,
 			    &(dbinfo->db_handle));
 	}
 
+	dlp_ReadOpenDBInfo(dbinfo->pilot_socket,dbinfo->db_handle,&conduit->total_records);
 	g_free(name);
 }
 
