@@ -15,16 +15,18 @@ void gpilot_context_init_user (GPilotContext *context);
 void gpilot_context_free (GPilotContext *context);
 
 typedef struct GPilotDevice {
-  gchar *device_name;
-  guint speed;
-  int fd;
-  GIOChannel *io;
+	gchar *name;
+	gchar *port;
+	guint speed;
+	/* These are used at runtime, to associate 
+	   an opened file with the device */
+	int fd;
+	GIOChannel *io;
 } GPilotDevice;
 
 GPilotDevice *gpilot_device_new (void);
 gint gpilot_device_init (GPilotDevice *device, gint i);
 void gpilot_device_free (GPilotDevice *device);
 
-
 #define GPILOT_DEVICE(s) ((GPilotDevice*)(s))
 #endif /* _GPILOT_USERINFO_H_ */
