@@ -1,5 +1,10 @@
-#define _XOPEN_SOURCE
 #include "config.h"
+#include <pthread.h>
+
+#ifdef USE_XOPEN_SOURCE
+#define _XOPEN_SOURCE 
+#endif
+
 #include <sys/types.h>
 #include <pwd.h>
 #include <errno.h>
@@ -14,11 +19,13 @@
 #include <signal.h>
 #include <pi-source.h>
 #include <pi-dlp.h>
+#include <pi-version.h>
 #include <sys/wait.h>
 #include <pwd.h>
 
 #define USE_NEW_IO
 #include "orbit_daemon_glue.h"
+#include "gpilot-gui.h"
 #include <errno.h>
 
 /* Grr, I needed a global variable.  Only used in local gpilotd */
@@ -26,12 +33,16 @@ GList *pending_children;
 /* Set to true when the config should be reloaded */
 gboolean reread_config;
 
-/* FIXME: this is bad. After each sync, I immediately get notified of
+/* NOTE: this is bad. After each sync, I immediately get notified of
    a event on the cradle just synced, this boolean is used to currently
    discard every 2nd sync. Which then means if you run two cradles,
-   cradle one syncs and you have to press sync twice on cradle two... */
+   cradle one syncs and you have to press sync twice on cradle two... 
+
+   If you experience a problem like this, enable the USE_UGLY define, and
+   recompile.
+*/
 gboolean ugly_boolean;
-#define USE_UGLY 1
+/* #define USE_UGLY 1 */
 
 /* #define USE_FORK */
 
@@ -45,6 +56,27 @@ gboolean device_err(GIOChannel *,
 void monitor_channel(GPilotDevice *,GPilotContext *);
 static void remove_pid_file(void);
 
+
+gint 
+device_equal_by_io(GPilotDevice *dev,GIOChannel *io) 
+{
+	return !(dev->io==io);
+}
+
+static void
+remove_device(GPilotContext *context,GPilotDevice *device) 
+{
+	GList *l;
+
+	g_message("Removing %s",device->name);
+
+	l = g_list_find(context->devices,device);
+	if (l != NULL) {
+		gpilot_device_free(l->data);
+		g_list_remove(context->devices,l);
+	}
+}
+
 static void 
 pilot_set_baud_rate(GPilotDevice *device) 
 {
@@ -69,13 +101,16 @@ pilot_connect(GPilotDevice *device)
 	}
 	
 	addr.pi_family = PI_AF_SLP;
-	strcpy(addr.pi_device,device->device_name);
+	strcpy(addr.pi_device,device->port);
 
 	ret = pi_bind(sd, (struct sockaddr*)&addr, sizeof(addr));
 	if(ret != 0) {
 		g_warning(_("Unable to bind to pilot"));
 		g_warning(_("This is a critical error, stopping gpilotd"));
-		exit (-1);
+		gpilot_gui_error_dialog(_("GnomePilot is unable to bind to %s (%s)\n"
+					  "This is a critical error, gpilotd will terminate.\n"),
+					device->name, device->port);
+		return -13; /* gpilot_gui_error terminates with exit -1 */
 	}
 
 	ret = pi_listen(sd,1);
@@ -138,9 +173,9 @@ do_cradle_events(int pfd,
 
   /* elements in events freed by gpc_request_purge calls
      in orbed_notify_completion */
-  events = gpc_queue_load_requests_for_cradle(device->device_name);
+  events = gpc_queue_load_requests_for_cradle(device->name);
 
-  g_message(_("Cradle %s has %d events"),device->device_name,g_list_length(events));
+  g_message(_("Cradle %s has %d events"),device->name,g_list_length(events));
 
   it = events;
 
@@ -215,6 +250,10 @@ do_sync(int pfd,
   stamp.sync_PC_Id=context->sync_PC_Id;
 
   g_message(_("HotSync button pressed, synchronizing pilot"));
+  g_message(_("Pilot ID is %ld, name is %s, owner is %s"),
+	    pu->userID,
+	    pilot->name,
+	    pu->username);
   
   /* Set a log entry in the pilot */
   {
@@ -320,8 +359,9 @@ static void sync_foreach(GPilotDevice *device, GPilotContext *context)
   GPilotPilot *pilot;
   int pfd;
   struct PilotUser pu;
-  GList *tmp;
+#ifdef USE_FORK
   void (*old_handler)(int);
+#endif
 
 #ifdef USE_FORK
   pid=fork();
@@ -370,17 +410,17 @@ static void sync_foreach(GPilotDevice *device, GPilotContext *context)
   if(do_cradle_events(pfd,context,&pu,pilot,device)) return;
 
   /* validate pilot */
-  tmp=g_list_find_custom(context->pilots, (gpointer)&pu.userID,
-			 (GCompareFunc)match_pilot_userID);
-  if(tmp == NULL) {
+  pilot = gpilot_find_pilot_by_id(pu.userID,context->pilots);
+  if(pilot == NULL) {
     g_warning(_("Unknown pilot, no userID/username match %ld"),pu.userID);
     /* FIXME: here, restoring one of the available pilots should be
        offered to the user. Of course with password prompt if the user
        has password set */
     pilot_disconnect(pfd);
+    gpilot_gui_warning_dialog(_("Unknown pilot - no pilots matches ID %ld\n"
+				"Use gnomecc to set pilot's ID"),pu.userID);
     /* _exit(1); */
   } else {
-    pilot=(GPilotPilot *)tmp->data;
     orbed_notify_connect(pilot->name,pu);
 
     if(pilot->passwd) {
@@ -406,59 +446,91 @@ static void sync_foreach(GPilotDevice *device, GPilotContext *context)
 #endif
 }
 
+#ifdef USE_FORK
 static gint match_pending_dev(pending_dev *d,pid_t *pid)
 {
   if(d->pending==*pid) return 0;
   return -1;
 }
-
-gint device_equal_by_io(GPilotDevice *dev,GIOChannel *io) {
-  return !(dev->io==io);
-}
-
-gboolean device_in(GIOChannel *io_channel,
-		   GIOCondition condition,
-		   GPilotContext *context) {
-  GPilotDevice *device;
-  GList *element;
-
-  /* FIXME: After reengaging the watch on the fd, this is apparantly
-   immediately called again. So every other time, I must ignore and retry.*/
-
-#ifdef USE_UGLY
- if(!ugly_boolean) {
-    ugly_boolean = TRUE;
-    return TRUE;
-  }
-  ugly_boolean = FALSE;
-#else
-  g_warning("Beware, testing without ugly_boolean var");
 #endif
 
-  element = g_list_find_custom(context->devices,io_channel,(GCompareFunc)device_equal_by_io);
+gboolean 
+device_in(GIOChannel *io_channel,
+	  GIOCondition condition,
+	  GPilotContext *context) {
+	GPilotDevice *device;
+	GList *element;
+	
+#ifdef USE_UGLY
+	/* FIXME: After reengaging the watch on the fd, this is apparantly
+	   immediately called again. So every other time, I must ignore and retry.*/
+	
+	if(!ugly_boolean) {
+		ugly_boolean = TRUE;
+		return TRUE;
+	}
+	ugly_boolean = FALSE;
+#endif
+	
+	element = g_list_find_custom(context->devices,io_channel,(GCompareFunc)device_equal_by_io);
 
-  if(element==NULL) {
-    g_warning("cannot find device for active IO channel");
-    return FALSE;
-  }
+	if(element==NULL) {
+		g_warning("cannot find device for active IO channel");
+		return FALSE;
+	}
+	
+	device = element->data;
+	g_message(_("Woke on %s"),device->name);
+	sync_foreach(device,context);
 
-  device = element->data;
-  g_message(_("Woke on %s"),device->device_name);
-  sync_foreach(device,context);
-  return FALSE;
+	return FALSE;
 }
 
-gboolean device_err(GIOChannel *io_channel,
-		    GIOCondition condition,
-		    GPilotContext *context) {
-  return FALSE;
+gboolean 
+device_err(GIOChannel *io_channel,
+	   GIOCondition condition,
+	   GPilotContext *context) {
+	GPilotDevice *device;
+	GList *element;
+	char tmp[10];
+
+	switch(condition) {
+	case G_IO_IN: strcpy(tmp,"G_IO_IN"); break;
+	case G_IO_OUT : strcpy(tmp,"G_IO_OUT"); break;
+	case G_IO_PRI : strcpy(tmp,"G_IO_PRI"); break;
+	case G_IO_ERR : strcpy(tmp,"G_IO_ERR"); break;
+	case G_IO_HUP : strcpy(tmp,"G_IO_HUP"); break;
+	case G_IO_NVAL: strcpy(tmp,"G_IO_NVAL"); break;
+	}
+	
+	element = g_list_find_custom(context->devices,io_channel,(GCompareFunc)device_equal_by_io);
+
+	if(element==NULL) {
+		/* We most likely end here if the device has just been removed.
+		   Eg. start gpilotd with a monitor on a XCopilot fake serial port,
+		   kill xcopilot and watch things blow up as the device fails */
+		g_warning("Device error on some device, caught %s",tmp); 
+		
+		return FALSE;
+	}
+	
+	device = element->data;
+
+	gpilot_gui_warning_dialog("Device error on %s (%s), caught %s",device->name,device->port,tmp); 
+	g_warning("Device error on %s (%s), caught %s",device->name,device->port,tmp);
+
+	remove_device(context,device);
+	
+	return FALSE;
 }
 
 void monitor_channel(GPilotDevice *dev,GPilotContext *context) {
-  g_message(_("Watching %s"),dev->device_name);
-
   g_io_add_watch(dev->io,G_IO_IN,(GIOFunc)device_in,(gpointer)context);
   g_io_add_watch(dev->io,G_IO_ERR,(GIOFunc)device_err,(gpointer)context);
+  g_io_add_watch(dev->io,G_IO_PRI,(GIOFunc)device_err,(gpointer)context);
+  g_io_add_watch(dev->io,G_IO_HUP,(GIOFunc)device_err,(gpointer)context);
+  g_io_add_watch(dev->io,G_IO_NVAL,(GIOFunc)device_err,(gpointer)context);
+  g_message(_("Watching %s (%s)"),dev->name,dev->port);
 }
 
 static void sig_hup_handler(int dummy)
@@ -481,6 +553,7 @@ static void sig_int_handler(int dummy) {
 	exit(1);
 }
 
+#ifdef USE_FORK
 static void sig_chld_handler(int dummy)
 {
   pid_t child;
@@ -504,7 +577,9 @@ static void sig_chld_handler(int dummy)
 
   signal(SIGCHLD,sig_chld_handler);
 }
+#endif
 
+#ifdef USE_FORK
 static void kill_foreach(pending_dev *p)
 {
   kill(p->pending, SIGTERM);
@@ -515,14 +590,19 @@ static void kill_all_pending_children(GPilotContext *context)
 {
   g_list_foreach(pending_children,(GFunc)kill_foreach,NULL);
 }
+#endif
 
 static void wait_for_sync_and_sync(GPilotContext *context) {
+#ifdef USE_FORK
   void (*old_handler)(int);
+#endif
 
   signal(SIGTERM,sig_term_handler);
   signal(SIGINT,sig_int_handler);
 
+#ifdef USE_FORK
   signal(SIGCHLD,sig_chld_handler);
+#endif
   signal(SIGHUP,sig_hup_handler);
 
   g_list_foreach(context->devices,(GFunc)monitor_channel,context);
@@ -533,14 +613,15 @@ static void wait_for_sync_and_sync(GPilotContext *context) {
   while(1) {
     if(reread_config) {
       g_message(_("Rereading configuration..."));
+#ifdef USE_FORK
       old_handler=signal(SIGCHLD,SIG_DFL);
       kill_all_pending_children(context);
-      /*
-	FIXME: clean_context(context);
-      */
+#endif
       gpilot_context_init_user (context);
+#ifdef USE_FORK
       old_handler(SIGCHLD);
       signal(SIGCHLD,old_handler);
+#endif
       reread_config=FALSE;
       g_list_foreach(context->devices,(GFunc)monitor_channel,context);
     }
@@ -631,6 +712,9 @@ main(int argc, char *argv[])
 	GPilotContext *context;
 	pid_t the_pid;
 	
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
 	the_pid=check_for_pid();
 
 	if(the_pid) {
@@ -648,12 +732,14 @@ main(int argc, char *argv[])
 	
 	/*gnome_init(PACKAGE,VERSION,argc,argv); */
 	gpilotd_corba_init(&argc,argv,&context);
-	
+
 	write_local_pid_file();
 	
 	reread_config=FALSE;
 	
 	g_message("%s %s starting...",PACKAGE,VERSION);
+	g_message("compiled for pilot-link version %d.%d.%d",
+		  PILOT_LINK_VERSION,PILOT_LINK_MAJOR,PILOT_LINK_MINOR);
 
 	wait_for_sync_and_sync(context);
 	
