@@ -2,6 +2,7 @@
 #include "gpilotd-app.h"
 #include <libgnorba/gnorba.h>
 
+/* #define LIBGPILOTD_DEBUG 1 */
 #define USE_GNORBA
 
 GNOME_Pilot_Daemon gpilotddaemon;
@@ -110,38 +111,45 @@ cb_conduit_start(PortableServer_Servant servant,
 static void
 cb_conduit_end(PortableServer_Servant servant,
 	       const CORBA_char *pilot_id,
+	       const CORBA_char *conduit_name,
 	       CORBA_Environment *ev) 
 {
-	LOG("cb_conduit_end(pilot=%s)",pilot_id);
-	(*gpilotd_conduit_end)(pilot_id);
+	LOG("cb_conduit_end(pilot=%s,conduit=%s)",pilot_id,conduit_name);
+	(*gpilotd_conduit_end)(pilot_id,conduit_name);
 }
 
 static void
 cb_conduit_progress(PortableServer_Servant servant,
 		    const CORBA_char *pilot_id,
-		    const CORBA_long current,
-		    const CORBA_long total,
+		    const CORBA_char *conduit,
+		    CORBA_long current,
+		    CORBA_long total,
 		    CORBA_Environment *ev) 
 {
-	LOG("cb_conduit_progress(pilot=%s,%d/%d)",pilot_id,current,total);
+	/*LOG("cb_conduit_progress(%s,%s,%d/%d)",pilot_id,conduit,current,total);*/
+	(*gpilotd_conduit_progress)(pilot_id,conduit,current,total);
 }
 
 static void
 cb_conduit_message(PortableServer_Servant servant,
 		   const CORBA_char *pilot_id,
+		   const CORBA_char *conduit,
 		   const CORBA_char *message,
 		   CORBA_Environment *ev) 
 {
 	LOG("cb_conduit_message(pilot=%s,message=%s)",pilot_id,message);
+	(*gpilotd_conduit_message)(pilot_id,conduit,message);
 }
 
 static void
 cb_conduit_error(PortableServer_Servant servant,
 		 const CORBA_char *pilot_id,
+		 const CORBA_char *conduit,
 		 const CORBA_char *message,
 		 CORBA_Environment *ev) 
 {
 	LOG("cb_conduit_error(pilot=%s,message=%s)",pilot_id,message);
+	(*gpilotd_conduit_error)(pilot_id,conduit,message);
 }
 
 PortableServer_ServantBase__epv base_epv = {
@@ -173,8 +181,9 @@ POA_GNOME_Pilot_Client callback_servant = { NULL, &callback_vepv };
 gint 
 gpilotd_connect() 
 {
-	gpilotddaemon = goad_server_activate_with_repo_id(NULL,"IDL:GNOME/Pilot/Daemon:1.0",
-							  GOAD_ACTIVATE_REMOTE,NULL);
+	gpilotddaemon = goad_server_activate_with_repo_id(NULL,
+							  "IDL:GNOME/Pilot/Daemon:1.0",
+							  0,NULL);
 	if (gpilotddaemon == NULL) return -1;
 	return 0;
 }
@@ -309,7 +318,7 @@ gpilotd_restore(gchar *pilot_id,
 		int timeout) 
 {
 	gint val;
-	
+
 	g_return_val_if_fail(gpilotddaemon!=NULL,-10);
 	g_return_val_if_fail(callback_obj!=NULL,-11);
 	g_return_val_if_fail(pilot_id!=NULL,-1);
@@ -367,9 +376,9 @@ gpilotd_install_file(gchar *pilot_id,
 	LOG("tmpfile = %s",filename);
 	
 	in = fopen(name,"rb");
-	g_return_val_if_fail(in!=NULL,0);
+	g_return_val_if_fail(in!=NULL,-12);
 	out = fopen(filename,"wb");
-	g_return_val_if_fail(out!=NULL,0);
+	g_return_val_if_fail(out!=NULL,-13);
 	
 	while(!feof(in)) {
 		size_t act;
@@ -379,7 +388,8 @@ gpilotd_install_file(gchar *pilot_id,
 	}
 	
 	fflush(out);
-	fclose(in); fclose(out);
+	fclose(in); 
+	fclose(out);
 	
 	val = GNOME_Pilot_Daemon_request_install(gpilotddaemon,
 						 callback_obj,
@@ -554,7 +564,9 @@ enum gpilotd_app_pilots { GPILOTD_APP_ALL_PILOTS,
 			  GPILOTD_APP_BY_UID };
 
 static int 
-gpilotd_get_pilots_action(gchar *name,enum gpilotd_app_pilots action,gchar ***pilots) 
+gpilotd_get_pilots_action(gchar *name,
+			  enum gpilotd_app_pilots action,
+			  gchar ***pilots) 
 {
 	GNOME_Pilot_StringSequence *pilotseq;
 
@@ -722,7 +734,8 @@ gpilotd_remove_request(gint handle)
 }
 
 gint 
-gpilotd_conduit(gchar *pilot_id,gchar *conduit,
+gpilotd_conduit(gchar *pilot_id,
+		gchar *conduit,
 		GNOME_Pilot_ConduitOperation operation,
 		GNOME_Pilot_Survival survival, 
 		int timeout) 
@@ -748,3 +761,85 @@ gpilotd_conduit(gchar *pilot_id,gchar *conduit,
 	}
 	return retval;
 }
+
+/* return val must be freed */
+gchar* 
+gpilotd_get_pilot_basedir(gchar *pilot) 
+{
+	CORBA_char *basedir;
+	gchar *retval;
+	
+	g_return_val_if_fail(pilot!=NULL,NULL);
+
+	basedir = GNOME_Pilot_Daemon_get_pilot_base_dir(gpilotddaemon,pilot,&ev);
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		g_warning ("lib-gpilotd:%d: Caught exception: %s",__LINE__, CORBA_exception_id (&ev));
+		CORBA_exception_free(&ev);
+		return NULL;
+	}
+
+	retval = g_strdup(basedir);
+	CORBA_free(basedir);
+
+	if (strlen(retval)==0) {
+		g_free(retval);
+		return g_strdup_printf("%s/%s",g_get_home_dir(),pilot);
+	}
+
+	return retval;	
+}
+
+/* return val must be freed */
+gchar* 
+gpilotd_get_pilot_basedir_by_id(guint32 pilot_id) 
+{
+	gchar *retval;
+	gchar *pilot_name;
+
+	pilot_name = gpilotd_get_name_from_id(pilot_id);
+	retval = gpilotd_get_pilot_basedir(pilot_name);
+
+	g_free(pilot_name);
+
+	return retval;
+}
+
+/* return val must be freed */
+gchar* gpilotd_get_name_from_id(guint32 id) {
+
+	CORBA_char *name;
+	gchar *retval;
+
+	name = GNOME_Pilot_Daemon_get_pilot_name_from_id(gpilotddaemon,id,&ev);
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		g_warning ("lib-gpilotd:%d: Caught exception: %s",__LINE__, CORBA_exception_id (&ev));
+		CORBA_exception_free(&ev);
+		return NULL;
+	}
+
+	retval = g_strdup(name);
+	CORBA_free(name);
+
+	if (strlen(retval)==0) {
+		g_free(retval);
+		return NULL;
+	}
+
+	return retval;	
+}
+
+guint32 gpilotd_get_id_from_name(gchar *name) {
+	CORBA_long id;
+	guint32 retval;
+
+	id = GNOME_Pilot_Daemon_get_pilot_id_from_name(gpilotddaemon,name,&ev);
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		g_warning ("lib-gpilotd:%d: Caught exception: %s",__LINE__, CORBA_exception_id (&ev));
+		CORBA_exception_free(&ev);
+		return -1;
+	}
+
+	retval = id;
+
+	return retval;	
+}
