@@ -14,7 +14,9 @@
 #include "gnome-pilot-conduit-backup.h"
 #include "gnome-pilot-conduit-file.h"
 #include "gnome-pilot-conduit-standard.h"
+#include "gpilot-gui.h"
 
+#define PROGRESS_STEPPING 10
 #define USE_GMODULE 
 
 #ifndef USE_GMODULE
@@ -75,7 +77,8 @@ static gint conduit_sync_default (GnomePilotConduitStandard *conduit,
 /* This is defined in gpilotd.  But we need to use it... */
 gchar *pilot_name_from_id(guint32 id,GPilotContext *context);
 
-
+/**************************************************************************/
+/* These are various match methods, used to do g_list_find's              */
 
 static gint
 find_matching_conduit_compare_func (GnomePilotConduit *conduit,
@@ -131,17 +134,81 @@ find_matching_conduit_name(GList *conlist,gchar *name)
     return NULL;
 }
 
+/**************************************************************************/
+/* Here comes conduit signal handler, used to call methods from 
+   orbit_daemon_glue                                                      */
+
+static void 
+conduit_progress_callback(GnomePilotConduit *conduit, 
+			  gint total,
+			  gint current,
+			  GnomePilotDBInfo *db) {
+	static gint top = 0;
+	gfloat tot_f,cur_f;
+	gint pct;
+
+	tot_f = total;
+	cur_f = current;
+	pct = abs(cur_f/(tot_f/100));
+	
+	if (pct < PROGRESS_STEPPING) top = 0; /* ensures resetting top */
+	if (pct >= top+PROGRESS_STEPPING) {
+		/* for every PROGRESS_STEPPING%, call the corba thingy */
+		top = pct;
+		orbed_notify_conduit_progress(db->pilotInfo->name,
+					      conduit,
+					      current,
+					      total);
+	}
+}
+
+static void 
+conduit_message_callback(GnomePilotConduit *conduit, 
+			 gchar *message,
+			 GnomePilotDBInfo *db) {
+	orbed_notify_conduit_message(db->pilotInfo->name,
+				     conduit,
+				     message);
+}
+
+static void 
+conduit_error_callback(GnomePilotConduit *conduit, 
+		       gchar *message,
+		       GnomePilotDBInfo *db) {
+	orbed_notify_conduit_error(db->pilotInfo->name,
+				   conduit,
+				   message);
+}
+
+/**************************************************************************/
 
 static void
 backup_foreach (GnomePilotConduitBackup *conduit, GnomePilotDBInfo *info)
 {
 
+	guint progress_h,error_h,message_h;
+
 	if (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit) == FALSE) {
 		g_error(_("non-backup conduit in backup conduit list"));
 		return;
 	}
 	g_assert (info != NULL);
+
+	progress_h = gtk_signal_connect(GTK_OBJECT(conduit),"progress",
+					(GtkSignalFunc)conduit_progress_callback,
+					info);
+	error_h = gtk_signal_connect(GTK_OBJECT(conduit),"error",
+				     (GtkSignalFunc)conduit_error_callback,
+				     info);
+	message_h = gtk_signal_connect(GTK_OBJECT(conduit),"message",
+				       (GtkSignalFunc)conduit_message_callback,
+				       info);
+
 	gnome_pilot_conduit_backup_backup (conduit, info);
+
+	gtk_signal_disconnect(GTK_OBJECT(conduit),progress_h);
+	gtk_signal_disconnect(GTK_OBJECT(conduit),error_h);
+	gtk_signal_disconnect(GTK_OBJECT(conduit),message_h);
 }
 
 static gint
@@ -161,7 +228,7 @@ iterate_dbs (gint pfd,
 	index = 0;
 	error = 0;
 	dbinfo.pilot_socket = pfd;
-	dbinfo.pilotId = pilot_name_from_id(pu->userID,context);
+	dbinfo.pilotInfo = gpilot_find_pilot_by_id(pu->userID,context->pilots);
 
 	while(1) {
 		if(dlp_OpenConduit(pfd) < 0) {
@@ -172,9 +239,18 @@ iterate_dbs (gint pfd,
 		if(dlp_ReadDBList(pfd, 0, 0x80, index, PI_DBINFO (&dbinfo)) < 0)
 			break;
 		index = PI_DBINFO (&dbinfo)->index + 1;
+		/*
+		g_message("DB: %20s: Exclude=%3s, Backup=%3s Flags=0x%8.8x Creator=0x%lx",
+			   PI_DBINFO(&dbinfo)->name,
+			   (PI_DBINFO(&dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)?"yes":"no",
+			   (PI_DBINFO(&dbinfo)->flags & dlpDBFlagBackup)?"yes":"no",
+			   PI_DBINFO(&dbinfo)->flags,
+			   PI_DBINFO(&dbinfo)->creator); 
+		*/
 		/* check if the base is marked as being excluded from sync */
-		/* g_message("DB: %20s: Exclude=%3s, Creator=0x%lx",PI_DBINFO(&dbinfo)->name,(PI_DBINFO(&dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)?"yes":"no",PI_DBINFO(&dbinfo)->creator); */
 		if (!(PI_DBINFO(&dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)) {
+			guint progress_h,error_h,message_h;
+
 			dbinfo.pu = pu;
 			dbinfo.pilot_socket = pfd;
 			dbinfo.manager_data = (void *) stamp;
@@ -190,13 +266,29 @@ iterate_dbs (gint pfd,
 						&dbinfo);
 				continue;
 			}
+			/* Now call the iter method on the conduit, after setting up
+			   the signals. The signals aren't set before, since we 
+			   want to pass dbinfo as the userdata, and we don't do it
+			   in "iter", since it's a parameterized funtion */
+			progress_h = gtk_signal_connect(GTK_OBJECT(conduit),"progress",
+							(GtkSignalFunc)conduit_progress_callback,
+							&dbinfo);
+			error_h = gtk_signal_connect(GTK_OBJECT(conduit),"error",
+						     (GtkSignalFunc)conduit_error_callback,
+						     &dbinfo);
+			message_h = gtk_signal_connect(GTK_OBJECT(conduit),"message",
+						       (GtkSignalFunc)conduit_message_callback,
+						       &dbinfo);
 			error = iter (GNOME_PILOT_CONDUIT_STANDARD (conduit), &dbinfo);
+
+			gtk_signal_disconnect(GTK_OBJECT(conduit),progress_h);
+			gtk_signal_disconnect(GTK_OBJECT(conduit),error_h);
+			gtk_signal_disconnect(GTK_OBJECT(conduit),message_h);
 		} else {
 			LOG("Base %s is to be ignored by sync",PI_DBINFO(&dbinfo)->name);
 			continue;
 		}
 	}
-	g_free(dbinfo.pilotId);
 	return error;
 }
 
@@ -209,11 +301,11 @@ conduit_synchronize(GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbinfo
 	if(gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit))!=NULL)
 		gpilot_add_log_entry(dbinfo->pilot_socket,"Synchronizing %s\n",
 				     gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit)));
-	orbed_notify_conduit_start(dbinfo->pilotId,
+	orbed_notify_conduit_start(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit),
 				   GnomePilotConduitSyncTypeSynchronize);
 	err = gnome_pilot_conduit_standard_synchronize (conduit,dbinfo);
-	orbed_notify_conduit_end(dbinfo->pilotId,
+	orbed_notify_conduit_end(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit));
 	return err;
 }
@@ -227,11 +319,11 @@ conduit_copy_to_pilot(GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbin
 	if(gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit))!=NULL)
 		gpilot_add_log_entry(dbinfo->pilot_socket,"Copy to pilot %s\n",
 				     gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit)));
-	orbed_notify_conduit_start(dbinfo->pilotId,
+	orbed_notify_conduit_start(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit),
 				   GnomePilotConduitSyncTypeCopyToPilot);
 	err = gnome_pilot_conduit_standard_copy_to_pilot (conduit,dbinfo);
-	orbed_notify_conduit_end(dbinfo->pilotId,
+	orbed_notify_conduit_end(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit));
 	return err;
 }
@@ -245,11 +337,11 @@ conduit_copy_from_pilot(GnomePilotConduitStandard *conduit, GnomePilotDBInfo *db
 	if(gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit))!=NULL)
 		gpilot_add_log_entry(dbinfo->pilot_socket,"Copy from pilot %s\n",
 				     gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit)));
-	orbed_notify_conduit_start(dbinfo->pilotId,
+	orbed_notify_conduit_start(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit),
 				   GnomePilotConduitSyncTypeCopyFromPilot);
 	err = gnome_pilot_conduit_standard_copy_from_pilot (conduit,dbinfo);
-	orbed_notify_conduit_end(dbinfo->pilotId,
+	orbed_notify_conduit_end(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit));
 	return err;
 }
@@ -263,11 +355,11 @@ conduit_merge_to_pilot(GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbi
 	if(gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit))!=NULL)
 		gpilot_add_log_entry(dbinfo->pilot_socket,"Merge to pilot %s\n",
 				     gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit)));
-	orbed_notify_conduit_start(dbinfo->pilotId,
+	orbed_notify_conduit_start(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit),
 				   GnomePilotConduitSyncTypeMergeToPilot);
 	err = gnome_pilot_conduit_standard_merge_to_pilot (conduit,dbinfo);
-	orbed_notify_conduit_end(dbinfo->pilotId,
+	orbed_notify_conduit_end(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit));
 	return err;
 }
@@ -281,11 +373,11 @@ conduit_merge_from_pilot(GnomePilotConduitStandard *conduit, GnomePilotDBInfo *d
 	if(gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit))!=NULL)
 		gpilot_add_log_entry(dbinfo->pilot_socket,"Merge from pilot %s\n",
 				     gnome_pilot_conduit_get_name(GNOME_PILOT_CONDUIT(conduit)));
-	orbed_notify_conduit_start(dbinfo->pilotId,
+	orbed_notify_conduit_start(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit),
 				   GnomePilotConduitSyncTypeMergeFromPilot);
 	err = gnome_pilot_conduit_standard_merge_from_pilot (conduit,dbinfo);
-	orbed_notify_conduit_end(dbinfo->pilotId,
+	orbed_notify_conduit_end(dbinfo->pilotInfo->name,
 				   GNOME_PILOT_CONDUIT(conduit));
 	return err;
 }
@@ -387,8 +479,23 @@ send_sysinfo_foreach(GPilotRequest *req, GnomePilotInstallCarrier *carrier)
 static void
 do_restore_foreach(GPilotRequest *req, GnomePilotInstallCarrier *carrier)
 {
-	g_error("Welcome to an non-implemented function!");
-	g_assert_not_reached();
+	GList *iterator;
+	g_assert(carrier!=NULL);
+
+	/* FIXME: if carrier.conduit_list is NULL, the user hasn't
+	  enabled any file conduits. The corba restore call should
+	  throw an exception or something.  */
+	iterator = carrier->conduit_list;
+	while( iterator != NULL ) {
+		/* FIXME: Do some amazing stuff here ! */
+		GnomePilotConduitFile *conduit;
+		conduit = GNOME_PILOT_CONDUIT_FILE(iterator->data);
+		gnome_pilot_conduit_file_restore_directory(conduit,carrier->pilot_socket,
+							   req->parameters.restore.directory);
+		iterator = iterator->next;
+	}
+
+
 	orbed_notify_completion (&req);
 }
 
@@ -468,9 +575,9 @@ gpilot_load_conduit(guint32 pilotId,
 		gtk_object_set_data (GTK_OBJECT (conduit), "manager_info", cmaninfo);
 	} else {
 #ifdef USE_GMODULE
-		g_error(_("Unable to open conduit %s: %s"),conduit_fn,g_module_error());
+		g_warning(_("Unable to open conduit %s: %s"),conduit_fn,g_module_error());
 #else
-		g_error(_("Unable to open conduit %s: %s"),conduit_fn,dlerror());
+		g_warning(_("Unable to open conduit %s: %s"),conduit_fn,dlerror());
 #endif
 		return NULL;
 	}
@@ -519,7 +626,7 @@ gpilot_load_conduits (GPilotPilot *pilot,
 			g_free(conduit_sync_type_str);
 
 			conduit_sync_type_str = gnome_config_get_string("first_sync_type");
-			if (conduit_sync_type_str) {
+			if (conduit_sync_type_str != NULL) {
 				cmaninfo->first_sync_type = gnome_pilot_conduit_sync_type_str_to_int (conduit_sync_type_str);
 				g_free(conduit_sync_type_str);
 			} else
@@ -529,7 +636,12 @@ gpilot_load_conduits (GPilotPilot *pilot,
 
 			conduit = gpilot_load_conduit(pilotId,conduit_fn,cmaninfo);
 			if (conduit == NULL) {
-				return;
+				g_message(_("Loading conduit \"%s\" failed!"),conduit_name[i]);
+				gpilot_gui_warning_dialog(_("Loading conduit \"%s\" failed!\n"
+							    "It is likely a problem with the file\n"
+							    "%s"),conduit_name[i],conduit_fn);
+				g_free(conduit_fn);
+				continue;
 			}
 
 			if (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit)) {
@@ -651,6 +763,7 @@ gboolean gpilot_initial_synchronize_operations(int pilot_socket,
 	g_message("Pilot has %d entries in restore queue",g_list_length(request_list));
 	if (g_list_length (request_list)) {
 		do_normal_sync_stuff = FALSE;
+		carrier.conduit_list = g_list_copy(file_conduit_list);
 		g_list_foreach(request_list,(GFunc)do_restore_foreach,&carrier);
 	}
 
@@ -811,7 +924,25 @@ gpilot_add_log_entry(int pilot_socket,
 		     gchar *entry, ...) 
 {
 	gchar *e;
-#define PILOT_NAME_NEED_SPACE
+
+	/* Pilot link before 0.9.3 has a bug in dlp_AddSyncLogEntry,
+	 that eats last char (the \n) from input. Thus we add a space
+	 if pilot link is an older version */
+
+#if PILOT_LINK_VERSION == 0
+  #if PILOT_LINK_MAJOR == 9
+    #if PILOT_LINK_MINOR < 3
+      /* pilot-link version less then 0.9.3 */
+      #define PILOT_NAME_NEED_SPACE
+    #endif /* PILOT_LINK_MINOR < 3 */
+  #else /* PILOT_LINK_MAJOR == 9 */
+    #if PILOT_LINK_MAJOR < 9
+      /* "pilot-link version less then 0.9.x */
+      #define PILOT_NAME_NEED_SPACE
+    #endif /* PILOT_LINK_MAJOR < 9 */
+  #endif /* PILOT_LINK_MAJOR == 9 */
+#endif /* PILOT_LINK_VERSION == 0 */
+
 #ifdef PILOT_NAME_NEED_SPACE
 	gchar *f;
 #endif
@@ -820,8 +951,6 @@ gpilot_add_log_entry(int pilot_socket,
 	va_start(ap,entry);
 	e = g_strdup_vprintf(entry,ap);
 #ifdef PILOT_NAME_NEED_SPACE
-	/* The extra f gchar* adds a space, since dlp_AddSyncLogEntry apparently
-	   eats the last char... must... file... bug... report... */
 	f = g_strdup_printf("%s ",e);
 	dlp_AddSyncLogEntry(pilot_socket,f);
 	g_free (f);
