@@ -38,7 +38,7 @@
     return;                                         \
   }
 
-/* two macros for throwing exceptions */
+/* some macros for throwing exceptions */
 #define gpthrow(exception,returnval)                             \
   {                                                              \
 	  GNOME_Pilot_##exception *exn;                          \
@@ -48,6 +48,16 @@
 	  return returnval;                                      \
   }
 
+#define gpthrow_with_settings(exception,returnval,name,commands) \
+  {                                                              \
+	  GNOME_Pilot_##exception *name;                         \
+          name = GNOME_Pilot_##exception##__alloc();             \
+          { commands; }                                          \
+	  CORBA_exception_set (ev, CORBA_USER_EXCEPTION,         \
+			       ex_GNOME_Pilot_##exception, name);\
+	  return returnval;                                      \
+  }
+
 #define gpthrow_no_val(exception)                                \
   {                                                              \
 	  GNOME_Pilot_##exception *exn;                          \
@@ -57,11 +67,25 @@
 	  return;                                                \
   }
 
+#define gpthrow_no_val_with_settings(exception,name,commands)    \
+  {                                                              \
+	  GNOME_Pilot_##exception *name;                         \
+          name = GNOME_Pilot_##exception##__alloc();             \
+          { commands; }                                          \
+	  CORBA_exception_set (ev, CORBA_USER_EXCEPTION,         \
+			       ex_GNOME_Pilot_##exception, name);\
+	  return;                                                \
+  }
+
 /* a macro for logging catched exceptions */
 #define LOGEXN(e) g_warning ("%s:%d Exception: %s\n",   \
 	       	          __FILE__,__LINE__,            \
 			  CORBA_exception_id (&e));
 
+/* CORBA_string_dup doesn't take its argument as a const, meaning
+   passing consts causes warnings. This macor circumvents that */
+#define CORBA_string_dup(s) CORBA_string_dup((CORBA_char*)s)
+
 /********************************************************************************/
 /*  Structures                                                                  */
 
@@ -71,6 +95,7 @@
 enum ForEachAction {
 	CALL_CONNECT,
 	CALL_DISCONNECT,
+	CALL_CONDUIT_PROGRESS,
 	CALL_CONDUIT_MESSAGE,
 	CALL_CONDUIT_ERROR,
 	CALL_CONDUIT_BEGIN,
@@ -82,7 +107,7 @@ typedef struct _GPilotd_notify_foreach_carrier GPilotd_notify_foreach_carrier;
 struct _GPilotd_notify_foreach_carrier {
 	gpointer id;
 	gpointer ptr1,ptr2,ptr3;
-	gint integer;
+	glong long1,long2;
 	enum ForEachAction action;
 	GSList *purge_list;
 };
@@ -209,7 +234,7 @@ gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 	*/
 	if(req.pilot_id==0) {
 		g_free(client_id);
-		gpthrow(UnknownPilot,0);
+		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
 	if(access(filename,R_OK)) {
 		g_free(client_id);
@@ -217,7 +242,7 @@ gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 	}
 
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = NULL;
+	req.cradle = NULL;
 	req.client_id = g_strdup(client_id);
 	req.parameters.install.filename = g_strdup(filename);
 	req.parameters.install.description = g_strdup(description);
@@ -227,6 +252,7 @@ gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 	return gpc_queue_store_request(req);
 }
 
+/* FIXME: look in manager.c, do_restore_foreach */
 static CORBA_unsigned_long
 gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 			      const GNOME_Pilot_Client cb,
@@ -254,18 +280,20 @@ gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 
 	if(req.pilot_id==0) {
 		g_free(client_id);
-		gpthrow(UnknownPilot,0);
+		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
-	if(!stat(directory,&statbuf)) {
+	if(stat(directory,&statbuf)!=0) {
 		g_free(client_id);
+		g_message("here");
 		gpthrow(MissingFile,0);
 	}
-	if(!(S_ISDIR(statbuf.st_mode) && access(directory,R_OK))) {
+	if(S_ISDIR(statbuf.st_mode) && access(directory,R_OK)!=0) {
 		g_free(client_id);
+		g_message("or here access=%d, S_ISDIR=%d",access(directory,R_OK),S_ISDIR(statbuf.st_mode));
 		gpthrow(MissingFile,0);
 	}
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = NULL;
+	req.cradle = NULL;
 	req.client_id = g_strdup(client_id);
 
 	req.parameters.restore.directory = g_strdup(directory);
@@ -298,14 +326,14 @@ gpilotd_corba_request_conduit(GNOME_Pilot_Daemon _obj,
 
 	if(req.pilot_id==0) {
 		g_free(client_id);
-		gpthrow(UnknownPilot,0);
+		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
 
 	/* FIXME: check for conduit existence, throw exn if not */
 
 	req.type = GREQ_CONDUIT;
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = NULL;
+	req.cradle = NULL;
 	req.client_id = g_strdup(client_id);
 
 	req.parameters.conduit.name = g_strdup(conduit_name);
@@ -356,7 +384,7 @@ gpilotd_corba_get_user_info(GNOME_Pilot_Daemon obj,
 	req.type = GREQ_GET_USERINFO;
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
 	req.pilot_id = 0;
-	req.device_name = g_strdup(cradle);
+	req.cradle = g_strdup(cradle);
 	req.client_id = g_strdup(client_id);
 
 	g_free(client_id);
@@ -384,10 +412,10 @@ gpilotd_corba_get_system_info(GNOME_Pilot_Daemon obj,
 	req.pilot_id = pilot_id_from_name(pilot_id,orb_context->gpilotd_context);
 	if(req.pilot_id==0) {
 		g_free(client_id);
-		gpthrow(UnknownPilot,0);
+		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = NULL;
+	req.cradle = NULL;
 	req.client_id = g_strdup(client_id);
 	
 	g_free(client_id);
@@ -419,7 +447,7 @@ gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 	req.type = GREQ_SET_USERINFO;
 	req.pilot_id = 0;
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = g_strdup(cradle);
+	req.cradle = g_strdup(cradle);
 	req.client_id = g_strdup(client_id);
 	req.parameters.set_userinfo.password = NULL;
 	req.parameters.set_userinfo.user_id = g_strdup(user->username);
@@ -457,7 +485,7 @@ gpilotd_corba_set_user_info_if_not_set(GNOME_Pilot_Daemon obj,
 	req.type = GREQ_NEW_USERINFO;
 	req.pilot_id = 0;
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.device_name = g_strdup(cradle);
+	req.cradle = g_strdup(cradle);
 	req.client_id = g_strdup(client_id);
 	req.parameters.set_userinfo.password = NULL;
 	req.parameters.set_userinfo.user_id = g_strdup(user->username);
@@ -509,7 +537,7 @@ gpilotd_corba_monitor_on(GNOME_Pilot_Daemon obj,
 
 	if(pilot_id_from_name(pilot_id,orb_context->gpilotd_context)==0) {
 		g_free(client_id);
-		gpthrow_no_val(UnknownPilot);
+		gpthrow_no_val_with_settings(UnknownPilot,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
 
 	if((pilots = g_hash_table_lookup(orb_context->monitors,client_id))==NULL) {
@@ -681,7 +709,7 @@ gpilotd_corba_monitor_off(GNOME_Pilot_Daemon obj,
 	LOG("monitor_off(pilot_id=\"%.10s\", client_id = %.20s...)",pilot_id,client_id);
 	if(pilot_id_from_name(pilot_id,orb_context->gpilotd_context)==0) {
 		g_free(client_id);
-		gpthrow_no_val(UnknownPilot);
+		gpthrow_no_val_with_settings(UnknownPilot,exn,exn->pilotId = CORBA_string_dup(pilot_id));
 	}
 	monitor_off_helper(pilot_id,client_id);
 
@@ -852,8 +880,8 @@ gpilotd_corba_get_cradles(GNOME_Pilot_Daemon obj,
 
 		/* FIXME: this could probably be prettyfied with some _foreach thingies... */
 		for(i=0;i<g_list_length(orb_context->gpilotd_context->devices);i++) {
-			cradles->_buffer[i] = CORBA_string_alloc(strlen(GPILOT_DEVICE(g_list_nth(orb_context->gpilotd_context->devices,i)->data)->device_name));
-			strcpy(cradles->_buffer[i],GPILOT_DEVICE(g_list_nth(orb_context->gpilotd_context->devices,i)->data)->device_name);
+			cradles->_buffer[i] = CORBA_string_alloc(strlen(GPILOT_DEVICE(g_list_nth(orb_context->gpilotd_context->devices,i)->data)->name));
+			strcpy(cradles->_buffer[i],GPILOT_DEVICE(g_list_nth(orb_context->gpilotd_context->devices,i)->data)->name);
 		}
 		return cradles;
 	} else 
@@ -898,7 +926,7 @@ gpilotd_corba_get_pilot_ids(GNOME_Pilot_Daemon obj,
 		
 		pilots = GNOME_Pilot_LongSequence__alloc();
 		pilots->_length = g_list_length(orb_context->gpilotd_context->pilots);
-		pilots->_buffer = CORBA_sequence_CORBA_string_allocbuf(pilots->_length);
+		pilots->_buffer = CORBA_sequence_CORBA_long_allocbuf(pilots->_length);
 
 		/* FIXME: this could probably be prettyfied with some _foreach thingies... */
 		for(i=0;i<g_list_length(orb_context->gpilotd_context->pilots);i++) {
@@ -1015,8 +1043,60 @@ gpilotd_corba_get_user_login_by_pilot(GNOME_Pilot_Daemon obj,
 	return NULL;
 }
 
-/*************************************************************************************/
+static CORBA_char* 
+gpilotd_get_pilot_base_dir(PortableServer_Servant _servant, 
+		     CORBA_char * pilot_id, 
+		     CORBA_Environment * ev) {
+	int i;
+	LOG("corba: get_pilot_base_dir(id=%s:",pilot_id);
+	
 
+	/* FIXME: this could probably be prettyfied with some _foreach thingies... */
+	if(g_list_length(orb_context->gpilotd_context->pilots)>0) {
+		/* FIXME: this could probably be prettyfied with some _foreach thingies... */
+		for(i=0;i<g_list_length(orb_context->gpilotd_context->pilots);i++) {
+			if(strcmp(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name,
+				  pilot_id)==0) {
+				LOG("match on %s",GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name);
+				if(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->sync_options.basedir!=NULL) {
+					return CORBA_string_dup(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->sync_options.basedir);
+				} else {
+					return CORBA_string_dup("");
+				}
+			}
+		}
+		LOG("no matches on %s",pilot_id);
+		return CORBA_string_dup("");
+	} else 
+		return CORBA_string_dup("");
+}
+
+static CORBA_long 
+gpilotd_get_pilot_id_from_name(PortableServer_Servant _servant, 
+			       CORBA_char * pilot_id, 
+			       CORBA_Environment * ev) {
+	LOG("corba: get_user_pilot_id_from_name");
+
+	return pilot_id_from_name(pilot_id,orb_context->gpilotd_context);
+}
+
+static CORBA_char* 
+gpilotd_get_pilot_name_from_id(PortableServer_Servant _servant, 
+			       CORBA_long pilot_id, 
+			       CORBA_Environment * ev) {
+	gchar *tmp;
+	CORBA_char *retval;
+	LOG("corba: get_pilot_name_from_id(id=%d)",pilot_id);
+
+	tmp = pilot_name_from_id(pilot_id,orb_context->gpilotd_context);
+	retval =  CORBA_string_dup(tmp);
+	g_free(tmp);
+
+	return retval;
+}
+
+
+/*************************************************************************************/
 static gint 
 match_pilot_and_name(const GPilotPilot *pilot,
 		     const gchar *name) 
@@ -1090,6 +1170,9 @@ POA_GNOME_Pilot_Daemon__epv daemon_epv = {
 	(gpointer)&gpilotd_corba_get_pilots_by_login,
 	(gpointer)&gpilotd_corba_get_user_name_by_pilot,
 	(gpointer)&gpilotd_corba_get_user_login_by_pilot,
+	(gpointer)&gpilotd_get_pilot_base_dir,
+	(gpointer)&gpilotd_get_pilot_id_from_name,
+	(gpointer)&gpilotd_get_pilot_name_from_id,
 	(gpointer)&gpilotd_corba_get_user_info,
 	(gpointer)&gpilotd_corba_set_user_info,
 	/*(gpointer)&gpilotd_corba_set_user_info_if_not_set,*/
@@ -1153,22 +1236,43 @@ orbed_notify_multi_purpose_foreach(gchar *IOR,
 	} else {
 		switch(carrier->action) {
 		case CALL_CONNECT:
-			GNOME_Pilot_Client_connect(cb, carrier->id, carrier->ptr1,&ev);
+			GNOME_Pilot_Client_connect(cb, 
+						   carrier->id, 
+						   carrier->ptr1,&ev);
 			break;
 		case CALL_DISCONNECT:
-			GNOME_Pilot_Client_disconnect(cb, carrier->id, &ev);
+			GNOME_Pilot_Client_disconnect(cb, 
+						      carrier->id, &ev);
 			break;
 		case CALL_CONDUIT_MESSAGE:
-			GNOME_Pilot_Client_conduit_message(cb, carrier->id, carrier->ptr1, &ev);
+			GNOME_Pilot_Client_conduit_message(cb, 
+							   carrier->id, 
+							   carrier->ptr1, 
+							   carrier->ptr2, &ev);
 			break;
 		case CALL_CONDUIT_ERROR:
-			GNOME_Pilot_Client_conduit_error(cb, carrier->id, carrier->ptr1, &ev);
+			GNOME_Pilot_Client_conduit_error(cb, 
+							 carrier->id, 
+							 carrier->ptr1, 
+							 carrier->ptr2, &ev);
+			break;
+		case CALL_CONDUIT_PROGRESS:
+			GNOME_Pilot_Client_conduit_progress(cb, 
+							    carrier->id, 
+							    carrier->ptr1, 
+							    carrier->long1,
+							    carrier->long2, &ev);
 			break;
 		case CALL_CONDUIT_BEGIN:
-			GNOME_Pilot_Client_conduit_start(cb, carrier->id, carrier->ptr1, carrier->ptr2, &ev);
+			GNOME_Pilot_Client_conduit_start(cb, 
+							 carrier->id, 
+							 carrier->ptr1, 
+							 carrier->ptr2, &ev);
 			break;
 		case CALL_CONDUIT_END:
-			GNOME_Pilot_Client_conduit_end(cb, carrier->id, &ev);
+			GNOME_Pilot_Client_conduit_end(cb, 
+						       carrier->id,
+						       carrier->ptr1, &ev);
 			break;
 		}
 		if(ev._major != CORBA_NO_EXCEPTION) {
@@ -1345,7 +1449,7 @@ orbed_notify_userinfo(struct PilotUser user_info,
 	user.userID = user_info.userID;
 	user.username = g_strdup(user_info.username);
   
-	GNOME_Pilot_Client_userinfo_requested(cb, (*req)->device_name, &user,&ev);
+	GNOME_Pilot_Client_userinfo_requested(cb, (*req)->cradle, &user,&ev);
 	if(ev._major != CORBA_NO_EXCEPTION) {
 		LOGEXN (ev);
 		CORBA_exception_free(&ev);
@@ -1418,11 +1522,11 @@ orbed_notify_conduit_start(gchar *pilot_id,
 	}
 
 	carrier.id = g_strdup(pilot_id);
-	carrier.ptr1 = gnome_pilot_conduit_get_name(conduit);
+	carrier.ptr1 = g_strdup(gnome_pilot_conduit_get_name(conduit));
 	if(GNOME_IS_PILOT_CONDUIT_STANDARD(conduit))
-		carrier.ptr2 = gnome_pilot_conduit_standard_get_db_name(conduit);
+		carrier.ptr2 = g_strdup(gnome_pilot_conduit_standard_get_db_name(GNOME_PILOT_CONDUIT_STANDARD(conduit)));
 	else
-		carrier.ptr2 = "";
+		carrier.ptr2 = g_strdup(_("(unknown DB)"));
 	carrier.purge_list = NULL;
 	carrier.action = CALL_CONDUIT_BEGIN;
 	g_slist_foreach(notifications->conduit,
@@ -1431,7 +1535,8 @@ orbed_notify_conduit_start(gchar *pilot_id,
 	/* FIXME: See note 1 at the end of this file */
 	if(carrier.purge_list) purge_ior_foreach(pilot_id,carrier.purge_list);
 	g_free(carrier.id);
-	
+	g_free(carrier.ptr1);
+	g_free(carrier.ptr2);
 }
 
 /********************************************************************************/
@@ -1448,7 +1553,7 @@ orbed_notify_conduit_end(gchar *pilot_id,
 	}
 
 	carrier.id = g_strdup(pilot_id);
-	carrier.ptr1 = gnome_pilot_conduit_get_name(conduit);
+	carrier.ptr1 = g_strdup(gnome_pilot_conduit_get_name(conduit));
 	carrier.purge_list = NULL;
 	carrier.action = CALL_CONDUIT_END;
 	g_slist_foreach(notifications->conduit,
@@ -1457,6 +1562,7 @@ orbed_notify_conduit_end(gchar *pilot_id,
 	/* FIXME: See note 1 at the end of this file */
 	if(carrier.purge_list) purge_ior_foreach(pilot_id,carrier.purge_list);
 	g_free(carrier.id);
+	g_free(carrier.ptr1);
 }
 
 /********************************************************************************/
@@ -1466,6 +1572,25 @@ void
 orbed_notify_conduit_error(gchar *pilot_id,				
 			   GnomePilotConduit *conduit,
 			   gchar *message) {
+	GPilotd_notify_foreach_carrier carrier;
+	GPilotd_Orb_Pilot_Notifications *notifications;
+	
+	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
+		return;
+	}
+
+	carrier.id = g_strdup(pilot_id);
+	carrier.ptr1 = g_strdup(gnome_pilot_conduit_get_name(conduit));
+	carrier.ptr2 = message;
+	carrier.purge_list = NULL;
+	carrier.action = CALL_CONDUIT_ERROR;
+	g_slist_foreach(notifications->conduit,
+			(GFunc)orbed_notify_multi_purpose_foreach,
+			&carrier);
+	/* FIXME: See note 1 at the end of this file */
+	if(carrier.purge_list) purge_ior_foreach(pilot_id,carrier.purge_list);
+	g_free(carrier.id);
+	g_free(carrier.ptr1);
 }
 
 /********************************************************************************/
@@ -1475,6 +1600,53 @@ void
 orbed_notify_conduit_message(gchar *pilot_id,				
 			     GnomePilotConduit *conduit,
 			     gchar *message) {
+	GPilotd_notify_foreach_carrier carrier;
+	GPilotd_Orb_Pilot_Notifications *notifications;
+	
+	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
+		return;
+	}
+
+	carrier.id = g_strdup(pilot_id);
+	carrier.ptr1 = g_strdup(gnome_pilot_conduit_get_name(conduit));
+	carrier.ptr2 = message;
+	carrier.purge_list = NULL;
+	carrier.action = CALL_CONDUIT_MESSAGE;
+	g_slist_foreach(notifications->conduit,
+			(GFunc)orbed_notify_multi_purpose_foreach,
+			&carrier);
+	/* FIXME: See note 1 at the end of this file */
+	if(carrier.purge_list) purge_ior_foreach(pilot_id,carrier.purge_list);
+	g_free(carrier.id);
+	g_free(carrier.ptr1);
+}
+
+void 
+orbed_notify_conduit_progress(gchar *pilot_id,				
+			      GnomePilotConduit *conduit,
+			      int current, 
+			      int total) {
+	GPilotd_notify_foreach_carrier carrier;
+	GPilotd_Orb_Pilot_Notifications *notifications;
+	
+	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
+		return;
+	}
+
+	carrier.id = g_strdup(pilot_id);
+	carrier.ptr1 = g_strdup(gnome_pilot_conduit_get_name(conduit));
+	carrier.long1 = current;
+	carrier.long2 = total;
+	g_message("orbed_notify_conduit_progress(cur=%ld,tot=%ld)",carrier.long1,carrier.long2);
+	carrier.purge_list = NULL;
+	carrier.action = CALL_CONDUIT_PROGRESS;
+	g_slist_foreach(notifications->conduit,
+			(GFunc)orbed_notify_multi_purpose_foreach,
+			&carrier);
+	/* FIXME: See note 1 at the end of this file */
+	if(carrier.purge_list) purge_ior_foreach(pilot_id,carrier.purge_list);
+	g_free(carrier.id);
+	g_free(carrier.ptr1);
 }
 
 /********************************************************************************/
