@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 1999-12-03 05:17+0100\n"
+"POT-Creation-Date: 2000-01-09 20:48+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -14,219 +14,218 @@ msgstr ""
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: ENCODING\n"
 
-#: applet/pilot.c:65 gpilotd/gpilotd.c:245
+#: applet/pilot.c:66 gpilotd/gpilotd.c:284
 msgid "Synchronizing..."
 msgstr ""
 
-#: applet/pilot.c:76
+#: applet/pilot.c:77
 msgid "Ready to synchronize"
 msgstr ""
 
-#: applet/pilot.c:209
+#: applet/pilot.c:240
 msgid "Ready to Synchronize"
 msgstr ""
 
-#: applet/pilot.c:373
+#: applet/pilot.c:408
 msgid ""
 "No directory to restore from.\n"
 "Please set the directory in the properties dialog."
 msgstr ""
 
-#: applet/pilot.c:380
+#: applet/pilot.c:415
 msgid ""
 "Press synchronize on the cradle to restore\n"
 " or cancel the operation."
 msgstr ""
 
-#: applet/pilot.c:389
+#: applet/pilot.c:424
 msgid "Restore request failed"
 msgstr ""
 
-#: applet/pilot.c:404
+#: applet/pilot.c:439
 msgid "GNOME PilotSync Properties"
 msgstr ""
 
-#: applet/pilot.c:425
+#: applet/pilot.c:460
 msgid "Execute when clicked "
 msgstr ""
 
-#: applet/pilot.c:439
+#: applet/pilot.c:474
 msgid "Directory to restore from "
 msgstr ""
 
-#: applet/pilot.c:451
+#: applet/pilot.c:486
 msgid "Display notices "
 msgstr ""
 
-#: applet/pilot.c:457
+#: applet/pilot.c:492
 msgid "Applet options"
 msgstr ""
 
-#: applet/pilot.c:488
+#: applet/pilot.c:523
 #, c-format
 msgid "Execution of %s failed"
 msgstr ""
 
-#: applet/pilot.c:561
+#: applet/pilot.c:596
 msgid "Gnome Pilot Applet"
 msgstr ""
 
-#: applet/pilot.c:563
+#: applet/pilot.c:598
 msgid "(C) 1998 Eskil Heyn Olsen"
 msgstr ""
 
-#: applet/pilot.c:565
+#: applet/pilot.c:600
 msgid "A dnd and gui monitor for gpilotd."
 msgstr ""
 
-#: applet/pilot.c:603
+#: applet/pilot.c:638
 msgid "Trying to connect to the GnomePilot Daemon"
 msgstr ""
 
-#: applet/pilot.c:637
+#: applet/pilot.c:672
 msgid "Restore..."
 msgstr ""
 
-#: applet/pilot.c:644
+#: applet/pilot.c:679
 msgid "Properties..."
 msgstr ""
 
-#: applet/pilot.c:650
+#: applet/pilot.c:685
 msgid "About..."
 msgstr ""
 
-#: applet/pilot.c:757 applet/pilot.c:758
+#: applet/pilot.c:792 applet/pilot.c:793
 msgid "Cannot initialize the GnomePilot Daemon"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:156
+#: capplet/gpilotd-control-applet.c:180
 msgid "Please specify a cradle port"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:162
-#, c-format
-msgid "Read/Write permissions on %s failed"
+#: capplet/gpilotd-control-applet.c:188
+msgid "Read/Write permissions failed on"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:303
+#: capplet/gpilotd-control-applet.c:190
+msgid "Check the permissions on the device and retry"
+msgstr ""
+
+#: capplet/gpilotd-control-applet.c:333
 msgid ""
 "Press synchronize on the cradle\n"
 " or cancel the operation."
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:375
+#: capplet/gpilotd-control-applet.c:405
 msgid "SyncPCid is a integer that uniquely identifies your PC"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:482
+#: capplet/gpilotd-control-applet.c:512
 msgid "Speed"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:529
+#: capplet/gpilotd-control-applet.c:559
 #, c-format
 msgid "Warning - unrecognized device %s, changing to /dev/pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:544
+#: capplet/gpilotd-control-applet.c:574
 #, c-format
 msgid "Warning - unrecognized speed %d, changing to 9600"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:615
+#: capplet/gpilotd-control-applet.c:645
 msgid "Pilot User ID"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:631
+#: capplet/gpilotd-control-applet.c:661
 msgid "Pilot Username"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:644
+#: capplet/gpilotd-control-applet.c:674
 msgid "Pilot Name"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:657
+#: capplet/gpilotd-control-applet.c:687
 msgid "get from pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:661
+#: capplet/gpilotd-control-applet.c:691
 msgid "send to pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:746
+#: capplet/gpilotd-control-applet.c:776
 msgid "Use conduit settings"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:752
+#: capplet/gpilotd-control-applet.c:782
 #: conduits/memo_file/memo_file_capplet.c:54
 msgid "Synchronize"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:758
+#: capplet/gpilotd-control-applet.c:788
 msgid "Copy from pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:764
+#: capplet/gpilotd-control-applet.c:794
 msgid "Copy to pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:770
+#: capplet/gpilotd-control-applet.c:800
 msgid "Merge from pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:776
+#: capplet/gpilotd-control-applet.c:806
 msgid "Merge to pilot"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:849
+#: capplet/gpilotd-control-applet.c:879
 msgid "Host ID"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:855
+#: capplet/gpilotd-control-applet.c:885
 msgid "User Configuration"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:861
+#: capplet/gpilotd-control-applet.c:891
 msgid "Pilot Device"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:867
+#: capplet/gpilotd-control-applet.c:897
 #: conduits/memo_file/memo_file_capplet.c:213
 msgid "Synchronize Action"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:892
+#: capplet/gpilotd-control-applet.c:926
 msgid "Error initializing gpilotd capplet"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:898
+#: capplet/gpilotd-control-applet.c:932
 msgid "Error loading pilot state, aborting"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:905 capplet/gpilotd-control-applet.c:906
-#: conduits/backup/backup-conduit-control-applet.c:409
-#: conduits/backup/backup-conduit-control-applet.c:410
+#: capplet/gpilotd-control-applet.c:939 capplet/gpilotd-control-applet.c:940
+#: conduits/backup/backup-conduit-control-applet.c:406
+#: conduits/backup/backup-conduit-control-applet.c:407
 #: conduits/email/email-conduit-control-applet.c:488
 #: conduits/email/email-conduit-control-applet.c:489
 #: conduits/file/file-conduit-control-applet.c:268
 #: conduits/file/file-conduit-control-applet.c:269
-#: conduits/memo/memo-conduit-control-applet.c:266
-#: conduits/memo/memo-conduit-control-applet.c:267
-#: conduits/memo_file/memo_file_capplet.c:505
-#: conduits/memo_file/memo_file_capplet.c:506
+#: conduits/memo_file/memo_file_capplet.c:503
+#: conduits/memo_file/memo_file_capplet.c:504
 msgid "Cannot initialze the GnomePilot Daemon"
 msgstr ""
 
-#: capplet/gpilotd-control-applet.c:911 capplet/gpilotd-control-applet.c:912
-#: conduits/backup/backup-conduit-control-applet.c:416
-#: conduits/backup/backup-conduit-control-applet.c:417
+#: capplet/gpilotd-control-applet.c:945 capplet/gpilotd-control-applet.c:946
+#: conduits/backup/backup-conduit-control-applet.c:413
+#: conduits/backup/backup-conduit-control-applet.c:414
 #: conduits/email/email-conduit-control-applet.c:495
 #: conduits/email/email-conduit-control-applet.c:496
 #: conduits/file/file-conduit-control-applet.c:275
 #: conduits/file/file-conduit-control-applet.c:276
-#: conduits/memo/memo-conduit-control-applet.c:273
-#: conduits/memo/memo-conduit-control-applet.c:274
-#: conduits/memo_file/memo_file_capplet.c:512
-#: conduits/memo_file/memo_file_capplet.c:513
+#: conduits/memo_file/memo_file_capplet.c:510
+#: conduits/memo_file/memo_file_capplet.c:511
 msgid "Cannot connect to the GnomePilot Daemon"
 msgstr ""
 
@@ -236,20 +235,15 @@ msgid ""
 "This tool only handles a single cradle, aborting..."
 msgstr ""
 
-#: capplet/pilot.c:117
+#: capplet/pilot.c:119
 msgid ""
 "More than one set of pilot information located.\n"
 "This tool only handles a single pilot, aborting..."
 msgstr ""
 
-#: conduits/address/address_conduit.c:194
-msgid "address"
-msgstr ""
-
 #: conduits/backup/backup-conduit-control-applet.c:139
 #: conduits/email/email-conduit-control-applet.c:149
 #: conduits/file/file-conduit-control-applet.c:112
-#: conduits/memo/memo-conduit-control-applet.c:113
 #: conduits/memo_file/memo_file_capplet.c:165
 msgid "Eskil Heyn Olsen <deity@eskil.dk>"
 msgstr ""
@@ -261,7 +255,6 @@ msgstr ""
 #: conduits/backup/backup-conduit-control-applet.c:142
 #: conduits/email/email-conduit-control-applet.c:152
 #: conduits/file/file-conduit-control-applet.c:115
-#: conduits/memo/memo-conduit-control-applet.c:116
 #: conduits/memo_file/memo_file_capplet.c:169
 msgid "(C) 1998 the Free Software Foundation"
 msgstr ""
@@ -277,7 +270,6 @@ msgstr ""
 #: conduits/backup/backup-conduit-control-applet.c:149
 #: conduits/email/email-conduit-control-applet.c:157
 #: conduits/file/file-conduit-control-applet.c:120
-#: conduits/memo/memo-conduit-control-applet.c:119
 #: conduits/memo_file/memo_file_capplet.c:174
 msgid "gnome-unknown.xpm"
 msgstr ""
@@ -285,7 +277,6 @@ msgstr ""
 #: conduits/backup/backup-conduit-control-applet.c:183
 #: conduits/email/email-conduit-control-applet.c:184
 #: conduits/file/file-conduit-control-applet.c:147
-#: conduits/memo/memo-conduit-control-applet.c:144
 msgid "Enabled"
 msgstr ""
 
@@ -304,7 +295,6 @@ msgstr ""
 #: conduits/backup/backup-conduit-control-applet.c:329
 #: conduits/email/email-conduit-control-applet.c:411
 #: conduits/file/file-conduit-control-applet.c:200
-#: conduits/memo/memo-conduit-control-applet.c:197
 msgid "Conduit state"
 msgstr ""
 
@@ -318,8 +308,6 @@ msgstr ""
 #: conduits/email/email-conduit-control-applet.c:472
 #: conduits/file/file-conduit-control-applet.c:241
 #: conduits/file/file-conduit-control-applet.c:252
-#: conduits/memo/memo-conduit-control-applet.c:238
-#: conduits/memo/memo-conduit-control-applet.c:249
 #: conduits/memo_file/memo_file_capplet.c:476
 #: conduits/memo_file/memo_file_capplet.c:487
 msgid ""
@@ -327,12 +315,24 @@ msgid ""
 "'Pilot Link Properties' capplet first."
 msgstr ""
 
-#: conduits/backup/backup_conduit.c:139
+#: conduits/backup/backup_conduit.c:67 conduits/backup/backup_conduit.c:69
 #, c-format
-msgid "Making backup of %s..."
+msgid ""
+"Unable to create directory:\n"
+"\t%s\n"
 msgstr ""
 
-#: conduits/backup/backup_conduit.c:143
+#: conduits/backup/backup_conduit.c:159 conduits/backup/backup_conduit.c:161
+#, c-format
+msgid "Making backup of %s"
+msgstr ""
+
+#: conduits/backup/backup_conduit.c:165 conduits/backup/backup_conduit.c:167
+#, c-format
+msgid "Could not create backup file %s"
+msgstr ""
+
+#: conduits/backup/backup_conduit.c:174 conduits/backup/backup_conduit.c:176
 #, c-format
 msgid "Backup of %s failed!"
 msgstr ""
@@ -404,47 +404,39 @@ msgstr ""
 msgid "Install delayed"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:106
-#: conduits/file/gpilot_install_file.c:107
+#: conduits/file/gpilot_install_file.c:131
+#: conduits/file/gpilot_install_file.c:132
 msgid "Cannot start the GnomePilot daemon"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:112
-#: conduits/file/gpilot_install_file.c:113
+#: conduits/file/gpilot_install_file.c:137
+#: conduits/file/gpilot_install_file.c:138
 msgid "Cannot connect to the GnomePilot daemon"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:119
-#: conduits/file/gpilot_install_file.c:120
+#: conduits/file/gpilot_install_file.c:144
+#: conduits/file/gpilot_install_file.c:145
 msgid "Unable to get pilot names"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:156
+#: conduits/file/gpilot_install_file.c:181
 msgid "Following files failed :\n"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:168
+#: conduits/file/gpilot_install_file.c:193
 msgid "Installing :\n"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:188
+#: conduits/file/gpilot_install_file.c:213
 msgid "No files to install"
 msgstr ""
 
-#: conduits/file/gpilot_install_file.c:190
+#: conduits/file/gpilot_install_file.c:215
 msgid ""
 "Press synchronize on the cradle to install\n"
 " or cancel the operation."
 msgstr ""
 
-#: conduits/memo/memo-conduit-control-applet.c:115
-msgid "Gpilotd memo conduit"
-msgstr ""
-
-#: conduits/memo/memo-conduit-control-applet.c:118
-msgid "Configuration utility for the memo conduit.\n"
-msgstr ""
-
 #. This array must be in the same order as enumerations
 #. in GnomePilotConduitSyncType as they are used as index.
 #. Custom type implies Disabled state.
@@ -516,230 +508,287 @@ msgstr ""
 msgid "Memo Conduit Options"
 msgstr ""
 
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:413
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:468
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:517
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:540
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:564
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:421
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:482
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:537
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:561
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:586
 msgid "Conduits initialization failed, aborting operation"
 msgstr ""
 
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:417
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:427
 msgid "Unable to delete all records in pilot database, aborting operation."
 msgstr ""
 
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:428
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:932
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:439
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:1016
 msgid "Conduit did not return a record"
 msgstr ""
 
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:472
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:488
 msgid "Unable to delete all records in local database, aborting operation."
 msgstr ""
 
-#: gpilotd/gnome-pilot-conduit-standard-abs.c:1215
+#: gpilotd/gnome-pilot-conduit-standard-abs.c:1299
 msgid "Error in conduit, newly added record could not be found"
 msgstr ""
 
-#: gpilotd/gpilot-structures.c:106
+#: gpilotd/gpilot-structures.c:114
 #, c-format
-msgid "Could not open device %s: reason: \"%s\"."
+msgid "Could not open device %s (%s): reason: \"%s\"."
 msgstr ""
 
-#: gpilotd/gpilot-structures.c:154
+#: gpilotd/gpilot-structures.c:118
+#, c-format
+msgid ""
+"GnomePilot could not open device %s (%s).\n"
+"Reason: \"%s\"."
+msgstr ""
+
+#: gpilotd/gpilot-structures.c:156
+msgid ""
+"No cradles configure.\n"
+"Please run gpilotd-control-applet (use gnomecc)\n"
+"to configure gnome-pilot."
+msgstr ""
+
+#: gpilotd/gpilot-structures.c:173
 msgid "No accessible devices available"
 msgstr ""
 
-#: gpilotd/gpilotd.c:76
+#: gpilotd/gpilot-structures.c:190
+msgid ""
+"No pilots configured.\n"
+"Please run gpilotd-control-applet (use gnomecc)\n"
+"to configure gnome-pilot."
+msgstr ""
+
+#: gpilotd/gpilotd.c:108
 msgid "Unable to bind to pilot"
 msgstr ""
 
-#: gpilotd/gpilotd.c:77
+#: gpilotd/gpilotd.c:109
 msgid "This is a critical error, stopping gpilotd"
 msgstr ""
 
-#: gpilotd/gpilotd.c:143
+#: gpilotd/gpilotd.c:110
+#, c-format
+msgid ""
+"GnomePilot is unable to bind to %s (%s)\n"
+"This is a critical error, gpilotd will terminate.\n"
+msgstr ""
+
+#: gpilotd/gpilotd.c:178
 #, c-format
 msgid "Cradle %s has %d events"
 msgstr ""
 
-#: gpilotd/gpilotd.c:152
+#: gpilotd/gpilotd.c:187
 msgid "Setting userinfo..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:159
+#: gpilotd/gpilotd.c:194
 msgid "Getting userinfo..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:217
+#: gpilotd/gpilotd.c:252
 msgid "HotSync button pressed, synchronizing pilot"
 msgstr ""
 
 #: gpilotd/gpilotd.c:253
+#, c-format
+msgid "Pilot ID is %ld, name is %s, owner is %s"
+msgstr ""
+
+#: gpilotd/gpilotd.c:292
 msgid "Copying to pilot..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:261
+#: gpilotd/gpilotd.c:300
 msgid "Copying from pilot..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:268
+#: gpilotd/gpilotd.c:307
 msgid "Merging to pilot..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:276
+#: gpilotd/gpilotd.c:315
 msgid "Merging from pilot..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:285
+#: gpilotd/gpilotd.c:324
 msgid "Using conduit settings for sync..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:293
+#: gpilotd/gpilotd.c:332
 msgid "Synchronization ended"
 msgstr ""
 
-#: gpilotd/gpilotd.c:296
+#: gpilotd/gpilotd.c:335
 msgid "Synchronization ended early"
 msgstr ""
 
-#: gpilotd/gpilotd.c:357 gpilotd/gpilotd.c:361
+#: gpilotd/gpilotd.c:397 gpilotd/gpilotd.c:401
 msgid "An error occured while listening for sync button press!"
 msgstr ""
 
-#: gpilotd/gpilotd.c:366
+#: gpilotd/gpilotd.c:406
 msgid "An error occured while getting the pilot's user data"
 msgstr ""
 
-#: gpilotd/gpilotd.c:376
+#: gpilotd/gpilotd.c:415
 #, c-format
 msgid "Unknown pilot, no userID/username match %ld"
 msgstr ""
 
-#: gpilotd/gpilotd.c:391
+#: gpilotd/gpilotd.c:420
+#, c-format
+msgid ""
+"Unknown pilot - no pilots matches ID %ld\n"
+"Use gnomecc to set pilot's ID"
+msgstr ""
+
+#: gpilotd/gpilotd.c:431
 msgid "Unknown pilot, no userID/username/pwd match"
 msgstr ""
 
-#: gpilotd/gpilotd.c:446
+#: gpilotd/gpilotd.c:483
 #, c-format
 msgid "Woke on %s"
 msgstr ""
 
-#: gpilotd/gpilotd.c:458
+#: gpilotd/gpilotd.c:533
 #, c-format
-msgid "Watching %s"
+msgid "Watching %s (%s)"
 msgstr ""
 
-#: gpilotd/gpilotd.c:471
+#: gpilotd/gpilotd.c:543
 msgid "Exiting (caught SIGTERM)..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:478
+#: gpilotd/gpilotd.c:550
 msgid "Exiting (caught SIGINT)..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:492
+#: gpilotd/gpilotd.c:565
 msgid "What, child exited, but wasn't pending???"
 msgstr ""
 
-#: gpilotd/gpilotd.c:535
+#: gpilotd/gpilotd.c:615
 msgid "Rereading configuration..."
 msgstr ""
 
-#: gpilotd/gpilotd.c:574 gpilotd/gpilotd.c:624
+#: gpilotd/gpilotd.c:655 gpilotd/gpilotd.c:705
 #, c-format
 msgid "Unable to find home directory for uid %d"
 msgstr ""
 
-#: gpilotd/gpilotd.c:618
+#: gpilotd/gpilotd.c:699
 #, c-format
 msgid "Unable to open or create file %s with read/write privs"
 msgstr ""
 
-#: gpilotd/gpilotd.c:644
+#: gpilotd/gpilotd.c:728
 #, c-format
 msgid "GnomePilot Daemon is already running, process %d, exiting..."
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:86
+#: gpilotd/lib-conduitmgmt.c:76
 msgid "Module loading not supported."
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:92 gpilotd/lib-conduitmgmt.c:107
+#: gpilotd/lib-conduitmgmt.c:82 gpilotd/lib-conduitmgmt.c:97
 #, c-format
 msgid "Malformed conduit, cannot find conduit_get_gpilot_conduit: %s"
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:99 gpilotd/lib-conduitmgmt.c:113
+#: gpilotd/lib-conduitmgmt.c:89 gpilotd/lib-conduitmgmt.c:103
 #, c-format
 msgid "Malformed conduit, cannot find conduit_destroy_gpilot_conduit: %s"
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:122
+#: gpilotd/lib-conduitmgmt.c:112
 msgid "Could not instantiate conduit"
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:133
+#: gpilotd/lib-conduitmgmt.c:123
 #, c-format
 msgid "Conduit %s has no name"
 msgstr ""
 
-#: gpilotd/lib-conduitmgmt.c:148
+#: gpilotd/lib-conduitmgmt.c:138
 #, c-format
 msgid "%s is not a conduit"
 msgstr ""
 
-#: gpilotd/manager.c:140
+#: gpilotd/manager.c:192
 msgid "non-backup conduit in backup conduit list"
 msgstr ""
 
-#: gpilotd/manager.c:307
+#: gpilotd/manager.c:399
 #, c-format
 msgid "Conduit %s's first synchronization..."
 msgstr ""
 
-#: gpilotd/manager.c:330
+#: gpilotd/manager.c:422
 #, c-format
 msgid "unknown syncing action (%d = %s).\n"
 msgstr ""
 
-#: gpilotd/manager.c:350
+#: gpilotd/manager.c:442
 #, c-format
 msgid "%s this request.type == %d is not a install/restore"
 msgstr ""
 
-#: gpilotd/manager.c:433 gpilotd/manager.c:449
+#: gpilotd/manager.c:540 gpilotd/manager.c:556
 #, c-format
 msgid "Malformed conduit %s, cannot find conduit_get_gpilot_conduit: %s"
 msgstr ""
 
-#: gpilotd/manager.c:441 gpilotd/manager.c:457
+#: gpilotd/manager.c:548 gpilotd/manager.c:564
 #, c-format
 msgid "Malformed conduit %s, cannot find conduit_destroy_gpilot_conduit: %s"
 msgstr ""
 
-#: gpilotd/manager.c:471 gpilotd/manager.c:473
+#: gpilotd/manager.c:578 gpilotd/manager.c:580
 #, c-format
 msgid "Unable to open conduit %s: %s"
 msgstr ""
 
-#: gpilotd/manager.c:507
+#: gpilotd/manager.c:614
 #, c-format
 msgid "Loading %d conduits..."
 msgstr ""
 
+#: gpilotd/manager.c:639
+#, c-format
+msgid "Loading conduit \"%s\" failed!"
+msgstr ""
+
+#: gpilotd/manager.c:640
+#, c-format
+msgid ""
+"Loading conduit \"%s\" failed!\n"
+"It is likely a problem with the file\n"
+"%s"
+msgstr ""
+
 #. FIXME: remove the bloody request, or the user will get this
 #. message every time
-#: gpilotd/manager.c:588
+#: gpilotd/manager.c:700
 #, c-format
 msgid "Conduit %s requested, but not found"
 msgstr ""
 
-#: gpilotd/manager.c:598
+#: gpilotd/manager.c:710
 #, c-format
 msgid "Conduit %s cannot be requested"
 msgstr ""
 
+#: gpilotd/orbit_daemon_glue.c:1529
+msgid "(unknown DB)"
+msgstr ""
+
 #: gpilotd/queue_io.c:361
 #, c-format
 msgid "fault: no request found for pilot %d, request %d"
